@@ -5,7 +5,6 @@
    * http://www.jus.uio.no/sisu/SiSU/download
 
  * Description: generates naive cgi search form for search of sisu database (pgsql sqlite)
-   * $Id$
 
  * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Ralph Amissah
 
@@ -48,16 +47,15 @@
 
 =end
 module  SiSU_CGI_pgsql                                                            #% database building documents
-  require "#{SiSU_lib}/sysenv"
-  require "#{SiSU_lib}/cgi_sql_common"
+  require SiSU_lib + '/sysenv'
+  require SiSU_lib + '/cgi_sql_common'
   include SiSU_CGI_sql
   class SiSU_search_pgsql
-    def initialize(webserv,cf)
-      @webserv,@cf=webserv,cf
-      #p @webserv
+    def initialize(opt,webserv)
+      @opt,@webserv=opt,webserv
       webrick_port=SiSU_Env::Info_dir.new.webrick_port
-      @port=case @webserv
-      when /webrick/
+      @port=case @opt.mod_s
+      when /--webserve?r?=webrick/
         @webrick_port=":#{webrick_port}"
         "        '#@webrick_port'\n"
       else
@@ -65,13 +63,13 @@ module  SiSU_CGI_pgsql
         "        ''\n"
       end
       @url_base="#{SiSU_Env::Info_dir.new.webserv_url_base}/_sisu/image"
-      @dir=SiSU_Env::Info_dir.new
-      @common=SiSU_CGI_sql::SiSU_CGI_common.new(@webserv,@cf,@port,@webrick_port,@url_base,@dir)
+      @env=SiSU_Env::Info_dir.new
+      @common=SiSU_CGI_sql::SiSU_CGI_common.new(@webserv,@opt.cmd,@port,@webrick_port,@url_base,@env)
     end
     def pgsql
       serve=Array.new
-      Dir.foreach(@dir.webserv_path) do |x| 
-        if x !~/^\./ and FileTest.directory?("#{@dir.webserv_path}/#{x}"): serve << x unless x =~/^_\S+/ 
+      Dir.foreach(@env.webserv_path) do |x| 
+        if x !~/^\./ and FileTest.directory?("#{@env.webserv_path}/#{x}"): serve << x unless x =~/^_\S+/ 
         end
       end
       serve.sort!
@@ -85,25 +83,28 @@ module  SiSU_CGI_pgsql
         f2 << %{          when /SiSU_#{x}/:        '<option value="SiSU_#{x}">#{x}</option>'\n} unless x =~/apache|sisu\/image/ #check
       end
       f2 << "          end\n"
-      output=File.open('sisu_pgsql.cgi','w')
-      output << header0 << header1 << @port << "user='#{@dir.user}'\n" << header2 << f1 << buttons << search_request << search_statement << @common.tail << @common.main1 << f2 << dbi_connect << @common.main2
-      a=%{        generated sisu_pgsql.cgi, 
-          BASED ON ALREADY EXISTING directories that could potentially be used to populate postgresql db, (-D)
-      }
-      tell=SiSU_Screen::Ansi.new(@cf,a) 
-      tell.print_grey
-      c=case @webserv
-      when /pwd/: ''
-      else "sudo cp -vi #{Dir.pwd}/sisu_pgsql.cgi /usr/lib/cgi-bin 
-            sudo chmod -v 755 /usr/lib/cgi-bin/sisu_pgsql.cgi
-            (copy sisu_pgsql.cgi to your cgi directory) and set file permissions to 755"
+      if FileTest.writable?('.') 
+        output=File.open('sisu_pgsql.cgi','w')
+        output << header0 << header1 << @port << "user='#{@env.user}'\n" << header2 << f1 << buttons << search_request << search_statement << @common.tail << @common.main1 << f2 << dbi_connect << @common.main2
+        a=%{        generated sisu_pgsql.cgi, 
+            BASED ON ALREADY EXISTING directories that could potentially be used to populate postgresql db, (-D)
+        }
+        tell=SiSU_Screen::Ansi.new(@opt.cmd,a) 
+        tell.print_grey
+        c=case @webserv
+        when /pwd/: ''
+        else "sudo cp -vi #{Dir.pwd}/sisu_pgsql.cgi /usr/lib/cgi-bin 
+                  sudo chmod -v 755 /usr/lib/cgi-bin/sisu_pgsql.cgi
+                  (copy sisu_pgsql.cgi to your cgi directory) and set file permissions to 755"
+        end
+        a=%{#{c}
+                  http://localhost#@webrick_port/cgi-bin/sisu_pgsql.cgi
+        }
+        b='(to create sisu sqlite database see "man sisu" and in particular the -D flag)'
+        tell=SiSU_Screen::Ansi.new(@opt.cmd,a,b) 
+        tell.warn
+      else puts 'failed in attempt to write sisu_pgsql.cgi to present directory,  is directory writable?'
       end
-      a=%{  #{c}
-            http://localhost#@webrick_port/cgi-bin/sisu_pgsql.cgi
-      }
-      b='(to create sisu sqlite database see "man sisu" and in particular the -D flag)'
-      tell=SiSU_Screen::Ansi.new(@cf,a,b) 
-      tell.warn
     end
     def header0
       <<-WOK_SQL
@@ -169,13 +170,14 @@ module  SiSU_CGI_pgsql
     end
     def header1
       <<-'WOK_SQL'
-      host=%x{echo $HOSTNAME}.chomp!
+      host='localhost'
+      #host=%x{echo $HOSTNAME}.chomp!
       @hosturl="http://#{host}" +
       WOK_SQL
     end
     def header2
       <<-'WOK_SQL'
-      #user='#{@dir.user}'
+      #user='#{@env.user}'
       @base="#@hosturl/cgi-bin/#@version.cgi"
       class Form
         def initialize(base,search_field,selected_db,checked_index,checked_text,checked_tip,checked_searched,checked_url,checked_echo,checked_sql,checked_all,checked_none,checked_ignore,search_note,the_can='')
