@@ -5,7 +5,6 @@
    * http://www.jus.uio.no/sisu/SiSU/download
 
  * Description: generates naive cgi search form for search of sisu database (pgsql sqlite)
-   * $Id$
 
  * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Ralph Amissah
 
@@ -48,16 +47,15 @@
 
 =end
 module  SiSU_CGI_sqlite                                                            #% database building documents
-  require "#{SiSU_lib}/sysenv"
-  require "#{SiSU_lib}/cgi_sql_common"
+  require SiSU_lib + '/sysenv'
+  require SiSU_lib + '/cgi_sql_common'
   include SiSU_CGI_sql
   class SiSU_search_sqlite
-    def initialize(webserv,cf)
-      @webserv,@cf=webserv,cf
-      #p @webserv
+    def initialize(opt,webserv)
+      @opt,@webserv=opt,webserv
       webrick_port=SiSU_Env::Info_dir.new.webrick_port
-      @port=case @webserv
-      when /webrick/
+      @port=case @opt.mod_s
+      when /--webserve?r?=webrick/
         @webrick_port=":#{webrick_port}"
         "        '#@webrick_port'\n"
       else
@@ -65,14 +63,14 @@ module  SiSU_CGI_sqlite
         "        ''\n"
       end
       @url_base="#{SiSU_Env::Info_dir.new.webserv_url_base}/_sisu/image"
-      @dir=SiSU_Env::Info_dir.new
-      @common=SiSU_CGI_sql::SiSU_CGI_common.new(@webserv,@cf,@port,@webrick_port,@url_base,@dir)
+      @env=SiSU_Env::Info_dir.new
+      @common=SiSU_CGI_sql::SiSU_CGI_common.new(@webserv,@opt.cmd,@port,@webrick_port,@url_base,@env)
     end
     def sqlite
       serve=Array.new
-      Dir.foreach(@dir.webserv_path) do |x| 
-        if x !~/^\./ and FileTest.directory?("#{@dir.webserv_path}/#{x}") 
-          if FileTest.file?("#{@dir.webserv_path}/#{x}/sisu_sqlite.db"): serve << x unless x =~/^_\S+/ 
+      Dir.foreach(@env.webserv_path) do |x| 
+        if x !~/^\./ and FileTest.directory?("#{@env.webserv_path}/#{x}") 
+          if FileTest.file?("#{@env.webserv_path}/#{x}/sisu_sqlite.db"): serve << x unless x =~/^_\S+/ 
           end
         end
       end
@@ -91,28 +89,31 @@ module  SiSU_CGI_sqlite
       f3 << %{          db_name='sisu_sqlite.db'\n}
       f3 << %{          db_sqlite=case cgi['db']\n}
       serve.each do |x|
-        f3 << %{          when /SiSU_#{x}/:                      "#{@dir.webserv_path}/#{x}/sisu_sqlite.db"\n}
+        f3 << %{          when /SiSU_#{x}/:                      "#{@env.webserv_path}/#{x}/sisu_sqlite.db"\n}
       end
       f3 << "          end\n"
-      output=File.open('sisu_sqlite.cgi','w')
-      output << header0 << header1 << @port << header2 << f1 << buttons << search_request << search_statement << @common.tail << @common.main1 << f2 << f3 << dbi_connect << @common.main2
-      a=%{        generated sisu_sqlite.cgi, 
-          BASED ON ALREADY CREATED sisu_sqlite.db OUTPUT, (-d) 
-      }
-      tell=SiSU_Screen::Ansi.new(@cf,a) 
-      tell.print_grey
-      c=case @webserv
-      when /pwd/: ''
-      else "sudo cp -vi #{Dir.pwd}/sisu_sqlite.cgi /usr/lib/cgi-bin 
-            sudo chmod -v 755 /usr/lib/cgi-bin/sisu_sqlite.cgi
-            (copy sisu_sqlite.cgi to your cgi directory) and set file permissions to 755"
+      if FileTest.writable?('.') 
+        output=File.open('sisu_sqlite.cgi','w')
+        output << header0 << header1 << @port << header2 << f1 << buttons << search_request << search_statement << @common.tail << @common.main1 << f2 << f3 << dbi_connect << @common.main2
+        a=%{        generated sisu_sqlite.cgi, 
+            BASED ON ALREADY CREATED sisu_sqlite.db OUTPUT, (-d) 
+        }
+        tell=SiSU_Screen::Ansi.new(@opt.cmd,a) 
+        tell.print_grey
+        c=case @webserv
+        when /pwd/: ''
+        else "sudo cp -vi #{Dir.pwd}/sisu_sqlite.cgi /usr/lib/cgi-bin 
+                  sudo chmod -v 755 /usr/lib/cgi-bin/sisu_sqlite.cgi
+                  (copy sisu_sqlite.cgi to your cgi directory) and set file permissions to 755"
+        end
+        a=%{#{c}
+                  http://localhost#@webrick_port/cgi-bin/sisu_sqlite.cgi
+        }
+        b='(to create sisu sqlite database see "man sisu" and in particular the -d flag)'
+        tell=SiSU_Screen::Ansi.new(@opt.cmd,a,b) 
+        tell.warn
+      else puts 'failed in attempt to write sisu_sqlite.cgi to present directory, is directory writable?'
       end
-      a=%{  #{c}
-            http://localhost#@webrick_port/cgi-bin/sisu_sqlite.cgi
-      }
-      b='(to create sisu sqlite database see "man sisu" and in particular the -d flag)'
-      tell=SiSU_Screen::Ansi.new(@cf,a,b) 
-      tell.warn
     end
     def header0
       <<-WOK_SQL
@@ -178,7 +179,8 @@ module  SiSU_CGI_sqlite
     end
     def header1
       <<-'WOK_SQL'
-      host=%x{echo $HOSTNAME}.chomp!
+      host='localhost'
+      #host=%x{echo $HOSTNAME}.chomp!
       @hosturl="http://#{host}" +
       WOK_SQL
     end
