@@ -5,8 +5,8 @@
    * http://www.jus.uio.no/sisu/SiSU/download
 
  * Description: modules related to locales, character encoding for different output generators [requires kirbybase]
-   * $Id$
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005 Ralph Amissah
+
+ * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Ralph Amissah
 
  * License: GPL 2 or later
 
@@ -40,7 +40,7 @@
   *  Standard SiSU meta-markup syntax, and the
   *  Standard SiSU object citation numbering and system
   
-  © Ralph Amissah 1997, current 2005.
+  © Ralph Amissah 1997, current 2006.
   All Rights Reserved.
 
  * Ralph Amissah: ralph@amissah.com
@@ -48,7 +48,7 @@
 =end
 module SiSU_character_encode
   require 'kirbybase'
-  require "#{SiSU_lib}/sysenv"
+  require SiSU_lib + '/sysenv'
   class Characters
     attr_accessor(:character_encoding,:glyph,:dec,:hex,:rb,:html,:html_name,:tex,:tex_licr,:tex_alt,:name)
     def initialize(&block)
@@ -58,9 +58,9 @@ module SiSU_character_encode
   class Create <Characters
     def initialize
       #NOTE places character_encoding.tbl in correct subdirectory ./_sisu_processing/encoding
-      #@dir=SiSU_Env::Info_dir.new
-      #dir=@dir.encoding
-      #@db=KirbyBase.new(:local,nil,nil,dir)
+      #@env=SiSU_Env::Info_dir.new
+      #env=@env.encoding
+      #@db=KirbyBase.new(:local,nil,nil,env)
       @db=KirbyBase.new                                         #default database location, pwd
       @ce_tbl=@db.create_table(:character_encoding, :glyph,:String, :dec,:Integer, :hex,:String, :rb,:String, :html,:String, :html_name,:String, :tex,:String, :tex_licr,:String, :tex_alt,:String, :name,:String)
     end
@@ -76,9 +76,9 @@ module SiSU_character_encode
   class Query
     def initialize(find='',show='')
       #NOTE character_encoding.tbl not read from subdirectory ./_sisu_processing/encoding
-      #@dir=SiSU_Env::Info_dir.new
-      #dir=@dir.encoding
-      #@db=KirbyBase.new(:local,nil,nil,dir)
+      #@env=SiSU_Env::Info_dir.new
+      #env=@env.encoding
+      #@db=KirbyBase.new(:local,nil,nil,env)
       @db=KirbyBase.new                                         #default database location, pwd
       @ce_tbl=@db.get_table(:character_encoding)
       @find=find
