@@ -5,8 +5,8 @@
    * http://www.jus.uio.no/sisu/SiSU/download
 
  * Description: common file for xml generation
-   * $Id$
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005 Ralph Amissah
+
+ * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Ralph Amissah
 
  * License: GPL 2 or later
 
@@ -40,7 +40,7 @@
   *  Standard SiSU meta-markup syntax, and the
   *  Standard SiSU object citation numbering and system
   
-  © Ralph Amissah 1997, current 2005.
+  © Ralph Amissah 1997, current 2006.
   All Rights Reserved.
 
  * Ralph Amissah: ralph@amissah.com
@@ -48,49 +48,51 @@
 =end
 module SiSU_text_parts 
   class Split_text_object
-    require "#{SiSU_lib}/param"
-    require "#{SiSU_lib}/xml_format"
+    require SiSU_lib + '/param'
+    require SiSU_lib + '/xml_format'
     include SiSU_Viz
     include SiSU_XML_format
     @@alt_id_count=0 #added
+    @@dp=nil
     attr_reader :format,:text,:ocn,:lev_para_ocn
     def initialize(md,para)
       @md,@para=md,para
       @format,@ocn='null','null'
+      #@format,@ocn=nil,nil
+      @@dp ||=SiSU_Env::Info_dir.new.digest_pattern
     end
     def lev_segname_para_ocn #using common_flatfile instead, watch #% watch closely
-      if @para =~/^(\d~|<:.+?>).+?<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>.*/
-        if /([1-6])~(\S+)\s+(\S.+?)<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/im.match(@para)
+      if @para =~/^(\d~|<:.+?>).+?<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>.*/
+        if /([1-6])~(\S+)\s+(\S.+?)<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/im.match(@para)
           @format,segname,@text,@ocn=$1,$2,$3,$4
           @format="#@format~#{segname}" # 
-        elsif  /([1-6]~)\s+(\S.+?)<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/im.match(@para)
+        elsif  /([1-6]~)\s+(\S.+?)<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/im.match(@para)
           @format,@text,@ocn=$1,$2,$3 #,$4
-        elsif /<:(.+?)>\s*(\S.+?)<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/im.match(@para)
+        elsif /<:(.+?)>\s*(\S.+?)<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/im.match(@para)
           @format,@text,@ocn=$1,$2,$3
-        elsif /([1-6])~(\S+)\s+(\S.+?)<~(0);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/im.match(@para)
+        elsif /([1-6])~(\S+)\s+(\S.+?)<~(0);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/im.match(@para)
           @@alt_id_count+=1
           @format,segname,@text,@ocn=$1,$2,$3,"x#{@@alt_id_count}"
           @format="#@format~#{segname}" # 
-        elsif  /([1-6]~)\s+(\S.+?)<~(0);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/im.match(@para)
+        elsif  /([1-6]~)\s+(\S.+?)<~(0);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/im.match(@para)
           @@alt_id_count+=1
           @format,@text,@ocn=$1,$2,"x#{@@alt_id_count}"
         end
       else
-        if /(.+?)<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/im.match(@para)
+        if /(.+?)<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/im.match(@para)
           @text,@ocn=$1,$2
         end
-        if @para !~/<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>|^$/ #added 2002w06
+        if @para !~/<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>|^$/ #added 2002w06
           @text=/(.+?)/im.match(@para)[1]
         end
         if /^(\d)~(?:\S+)?\s+(.+)/im.match(@para)
           @format,@text=$1,$2
         end
       end
-      @lev_para_ocn=if @para =~/.+<~\d+;(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/
+      @lev_para_ocn=if @para =~/.+<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/
         SiSU_XML_format::Format_scroll.new(@md,@format,@text,@ocn)
       else
-        SiSU_XML_format::Format_scroll.new(@md,@format,@text,'<~0;(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>')
-        #@para.gsub!(/4~(\S+)?\s*/,"") # problem added 2002w06 if @para=~/4~/
+        SiSU_XML_format::Format_scroll.new(@md,@format,@text,"<~0;(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>")
       end
       self
     end
@@ -284,7 +286,7 @@ module SiSU_XML_character
   end
 end
 module SiSU_XML_tags #Format
-  require "#{SiSU_lib}/param"
+  require SiSU_lib + '/param'
   include SiSU_Param
   include SiSU_Viz
   class RDF
@@ -371,9 +373,9 @@ module SiSU_XML_tags #Format
         @rdf_language=%{    dc.language="#{@md.dc_language[:name]}"\n} 
         @dc_language=%{  <meta name="dc.language" content="#{@md.dc_language[:name]}" />\n}
       end
-      if @md.original_language[:name]                                            
-        @rdf_original_language=%{    dc.language="#{@md.original_language[:name]}"\n} 
-        @original_language=%{  <meta name="dc.language" content="#{@md.original_language[:name]}" />\n}
+      if @md.language_original[:name]                                            
+        @rdf_language_original=%{    dc.language="#{@md.language_original[:name]}"\n} 
+        @language_original=%{  <meta name="dc.language" content="#{@md.language_original[:name]}" />\n}
       end
       if @md.dc_relation                                                         # DublinCore 13 - relation
         @rdf_relation=%{    dc.relation="#{@md.dc_relation}"\n}
@@ -419,18 +421,18 @@ module SiSU_XML_tags #Format
       rdftoc
     end
     def comment_xml
-      generator="Generated by: #{@md.sisuversion[:project]} #{@md.sisuversion[:version]} of #{@md.sisuversion[:date_stamp]} (#{@md.sisuversion[:date]})"  if @md.sisuversion[:version]
+      generator="Generated by: #{@md.sisu_version[:project]} #{@md.sisu_version[:version]} of #{@md.sisu_version[:date_stamp]} (#{@md.sisu_version[:date]})"  if @md.sisu_version[:version]
       lastdone="Last Generated on: #{Time.now}"
-      rubyv="Ruby version: #{@md.rubyversion}"
-      vc=if @md.rc_info
-        "Source file: #{@md.rc_filename} version: #{@md.rc_vnumber} of: #{@md.rc_date}"
+      rubyv="Ruby version: #{@md.ruby_version}"
+      sc=if @md.sc_info
+        "Source file: #{@md.sc_filename} version: #{@md.sc_number} of: #{@md.sc_date}"
       else ''
       end
 <<WOK
 <!-- Document processing information:
      * #{generator}
      * #{rubyv}
-     * #{vc}
+     * #{sc}
      * #{lastdone}
      * SiSU http://www.jus.uio.no/sisu
 -->
@@ -465,8 +467,10 @@ module SiSU_Tables
   class Table_xml <Table
     @@tablehead=0
     @@tablefoot=Array.new #watch #bug??? #check was @@tablefoot
+    @@dp=nil
     def initialize(one,ocn='')
       @one,@parablock,@ocn,@margin,@paragraph,@table=one,one,ocn,SiSU_Viz::Margin.new,SiSU_Viz::Paragraph.new,SiSU_Viz::Table.new
+      @@dp ||=SiSU_Env::Info_dir.new.digest_pattern
     end
     def table
       m=@parablock[/<!f(.+?)!>/,1]
@@ -484,7 +488,7 @@ module SiSU_Tables
         #@@tablefoot.each {|x| tablefoot << %{<p align="center"><font size=2><i>#{x}</i></font></p>\n}}
         @@tablefoot.each {|x| tablefoot << ''}
         @@tablefoot=Array.new
-        @parablock.gsub!(/<!TZ!>\s+<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/,"</table>\n") # +
+        @parablock.gsub!(/<!TZ!>\s+<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/,"</table>\n") # +
       end
       if @@tablehead == 1
         if @parablock =~/¡¡/
