@@ -5,8 +5,8 @@
    * http://www.jus.uio.no/sisu/SiSU/download
 
  * Description: css stylesheets
-   * $Id$
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005 Ralph Amissah
+
+ * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Ralph Amissah
 
  * License: GPL 2 or later
 
@@ -40,15 +40,15 @@
   *  Standard SiSU meta-markup syntax, and the
   *  Standard SiSU object citation numbering and system
   
-  © Ralph Amissah 1997, current 2005.
+  © Ralph Amissah 1997, current 2006.
   All Rights Reserved.
 
  * Ralph Amissah: ralph@amissah.com
                   ralph.amissah@gmail.com
 =end
 module SiSU_Style
-  require "#{SiSU_lib}/sysenv"
-  require "#{SiSU_lib}/color_hex_triplets"
+  require SiSU_lib + '/sysenv'
+  require SiSU_lib + '/color_hex_triplets'
   include SiSU_Hex_triplets
   class CSS
     def initialize
@@ -262,21 +262,21 @@ WOK
     margin-right: 5mm;
     text-align: right;
   }
-  p.wmap_word {
+  p.concordance_word {
     line-height: 150%;
     font-weight: bold;
     display: inline;
     margin-top: 4px;
     margin-bottom: 1px;
   }
-  p.wmap_count {
+  p.concordance_count {
     font-size: 80%;
     color: #777777;
     display: inline;
     margin-left: 0mm;
     text-indent: 0mm;
   }
-  p.wmap_object {
+  p.concordance_object {
     font-size: 80%;
     font-weight: normal;
     line-height: 120%;
@@ -332,6 +332,9 @@ WOK
     margin-top: 20px;
     margin-bottom: 10px;
   }
+  h1.center, h2.center, h3.center, h4.center, h5.center, h6.center {
+    text-align: center;
+  }
   ul {
     list-style: none;
   }
@@ -1110,10 +1113,10 @@ WOK
       margin-bottom: 20px;
       background-color: #dddddd;
     }
-    version_control {
+    source_control {
       display: block;
     }
-    dc,vc,keywords,copyright {
+    dc,sc,keywords,copyright {
       display: block;
       font-family: #@fonts;
       color: blue;
@@ -1127,7 +1130,7 @@ WOK
       margin-top: 0px;
       margin-bottom: 0px;
     }
-    vc {
+    sc {
       color: green;
     }
     keywords,copyright {
@@ -1297,10 +1300,10 @@ WOK
       margin-bottom: 20px;
       background-color: #dddddd;
     }
-    version_control {
+    source_control {
       display: block;
     }
-    dc,vc,keywords,copyright {
+    dc,sc,keywords,copyright {
       display: block;
       font-family: #@fonts;
       color: blue;
@@ -1314,7 +1317,7 @@ WOK
       margin-top: 0px;
       margin-bottom: 0px;
     }
-    vc {
+    sc {
       color: green;
     }
     keywords,copyright {
@@ -1498,10 +1501,10 @@ WOK
       margin-bottom: 20px;
       background-color: #dddddd;
     }
-    version_control {
+    source_control {
       display: block;
     }
-    dc,vc,keywords,copyright {
+    dc,sc,keywords,copyright {
       display: block;
       font-family: #@fonts;
       color: blue;
@@ -1515,7 +1518,7 @@ WOK
       margin-top: 0px;
       margin-bottom: 0px;
     }
-    vc {
+    sc {
       color: green;
     }
     keywords,copyright {
