@@ -5,8 +5,8 @@
    * http://www.jus.uio.no/sisu/SiSU/download
 
  * Description: Default values (reset by skins)
-   * $Id$
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005 Ralph Amissah
+
+ * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Ralph Amissah
 
  * License: GPL 2 or later
 
@@ -40,7 +40,7 @@
   *  Standard SiSU meta-markup syntax, and the
   *  Standard SiSU object citation numbering and system
   
-  © Ralph Amissah 1997, current 2005.
+  © Ralph Amissah 1997, current 2006.
   All Rights Reserved.
 
  * Ralph Amissah: ralph@amissah.com
@@ -49,9 +49,9 @@
 $latex_run=nil
 module SiSU_Viz
   require 'uri'
-  require "#{SiSU_lib}/sysenv"
+  require SiSU_lib + '/sysenv'
   include SiSU_Env
-  require "#{SiSU_lib}/css"
+  require SiSU_lib + '/css'
   include SiSU_Style
   class JavaScript
     attr_reader :sponsor,:catalogue,:books,:journals,:conferences,:services,:mail
@@ -120,7 +120,7 @@ module SiSU_Viz
     end
     def pdf
     end
-    def wmap
+    def concordance
     end
     def instruments
     end
@@ -397,7 +397,7 @@ module SiSU_Viz
     end
     def generator_comment
       v=SiSU_Env::Info_version.new.get_version
-      %{  <!-- #{v[:project]} #{v[:version]} of #{v[:date_stamp]} (#{v[:date]}) (n*x and Ruby!)" http://www.jus.uio.no/sisu -->}
+      %{  <!- #{v[:project]} #{v[:version]} of #{v[:date_stamp]} (#{v[:date]}) (n*x and Ruby!)" http://www.jus.uio.no/sisu ->}
     end
     def hp
       '&nbsp;SiSU'
@@ -428,7 +428,7 @@ module SiSU_Viz
           when /\/i$/: 'i'
           else         ''
           end
-          r.gsub!(/^\/(.+?)\/i?/,"\\1")
+          r.gsub!(/^\/(.+?)\/i?/,'\1')
           r.gsub!(/\(/,'(?:') # avoid need to escape use of brackets within regex provided
           m='\b(' + r + ')\b'
           make[:str]
@@ -449,7 +449,7 @@ module SiSU_Viz
           when /\/i$/: 'i'
           else         ''
           end
-          r.gsub!(/^\/(.+?)\/i?/,"\\1")
+          r.gsub!(/^\/(.+?)\/i?/,'\1')
           r.gsub!(/\(/,'(?:') # avoid need to escape use of brackets within regex provided
           m='\b(' + r + ')\b'
           make[:str]
@@ -467,16 +467,16 @@ module SiSU_Viz
       @font=Font.new
     end
     def txt
-      %{<p align="justify"><font #{@font.size_txt} #{@font.color} #{@font.face}>}
+      %{<p class="normal">}
     end
     def txt_00
-      %{<p align="justify"><font #{@font.size_txt_00} #{@font.color} #{@font.face}>}
+      %{<p class="justify">}
     end
     def font_citation
       %{<font #{@font.size_txt} #{@font.face}>}
     end
     def endnote
-      %{<p align="justify"><font #{@font.size_endnote} #{@font.color} #{@font.face}>}
+      %{<p class="endnote">}
     end
     def table
       %{<p align="left"><font #{@font.small} #{@font.color} #{@font.face}>}
@@ -484,37 +484,22 @@ module SiSU_Viz
     def table_xml
     end
     def tiny
-      %{<p align="justify"><font #{@font.tiny} #{@font.color} #{@font.face}>}
+      %{<p class="tiny">}
     end
     def small
-      %{<p align="justify"><font #{@font.small} #{@font.color} #{@font.face}>} # keep but not used?
+      %{<p class="small">} # keep but not used?
     end
-    def fontTiny
+    def font_tiny
       %{<font #{@font.tiny} #{@font.face}>}
     end
-    def fontSmall
+    def font_small
       %{<font #{@font.small} #{@font.face}>}
     end
-    def header_title
-      %{<p align="justify"><font #{@font.size_title} color="#0000ff" #{@font.face}>}
+    def heading_1
+      %{<h1>}
     end
-    def header_1
-      %{<p align="center"><font #{@font.size_header_1} color="#000000" #{@font.face}>}
-    end
-    def header_2
-      %{<p align="center"><font #{@font.size_header_2} color="#000000" #{@font.face}>}
-    end
-    def header_3
-      %{<p align="center"><font #{@font.size_header_3} color="#990000" #{@font.face}>}
-    end
-    def header_4
-      %{<p align="center"><font #{@font.size_header_4} color="#ff0000" #{@font.face}>}
-    end
-    def header_5
-      %{<p align="center"><font #{@font.size_header_5} color="#ff0000" #{@font.face}>}
-    end
-    def header_6
-      %{<p align="center"><font #{@font.size_header_6} color="#ff0000" #{@font.face}>}
+    def heading_1_center
+      %{<h1 class="center">}
     end
   end
   class Table
@@ -639,7 +624,7 @@ module SiSU_Viz
       @color=Color.new
     end
     def num
-      %{</font> </td><td width="4%" align="right" valign="top">}
+      %{</p> </td><td width="4%" align="right" valign="top">}
     end
     def numless
       %{</td><td width="4%" align="right" valign="top">}
@@ -763,6 +748,156 @@ module SiSU_Viz
       %{<table summary="" width="100%" border="0" cellpadding=#{@table.cellpad_small_paper_margins} bgcolor=#{@color.paper} align="justify">\n<tr><td>\n<font color="#000000"><p />\n}
     end
   end
+  class TeX #unit: mm
+    def initialize(papersize='')
+      @papersize=papersize
+    end
+    def a4
+      def portrait
+        def w
+          160
+        end
+        def h
+          228
+        end
+        def img_px
+          450
+        end
+        self
+      end
+      def landscape
+        def w
+          262
+        end
+        def h
+          168
+        end
+        def img_px
+          348
+        end
+        self
+      end
+      self
+    end
+    def letter
+      def portrait
+        def w
+          166
+        end
+        def h
+          216
+        end
+        def img_px
+          468
+        end
+        self
+      end
+      def landscape
+        def w
+          234
+        end
+        def h
+          166
+        end
+        def img_px
+          310
+        end
+        self
+      end
+      self
+    end
+    def legal
+      def portrait
+        def w
+          168
+        end
+        def h
+          294
+        end
+        def img_px
+          474
+        end
+        self
+      end
+      def landscape
+        def w
+          314
+        end
+        def h
+          166
+        end
+        def img_px
+          420
+        end
+        self
+      end
+      self
+    end
+    def b5
+      def portrait
+        def w
+          126
+        end
+        def h
+          180
+        end
+        def img_px
+          356
+        end
+        self
+      end
+      def landscape
+        def w
+          216
+        end
+        def h
+          136
+        end
+        def img_px
+          280
+        end
+        self
+      end
+      self
+    end
+    def a5
+      def portrait
+        def w
+          100
+        end
+        def h
+          144
+        end
+        def img_px
+          280
+        end
+        self
+      end
+      def landscape
+        def w
+          176
+        end
+        def h
+          110
+        end
+        def img_px
+          230
+        end
+        self
+      end
+      self
+    end
+    def dimensions
+      d=case @papersize
+      when /a4/:     a4
+      when /letter/: letter
+      when /legal/:  legal
+      when /b5/:     b5
+      when /a5/:     a5
+      else           a4
+      end
+    end
+  end
   class Png
     def initialize
       @url=Url.new
@@ -808,7 +943,7 @@ module SiSU_Viz
       %{<img border="0" height="15" width="18" src="#{@url.path_image}/#{@icon.pdf}" alt="PDF landscape" />}
     end
     def wmp
-      %{<img border="0" height="15" width="15" src="#{@url.path_image}/#{@icon.wmp}" alt="Word Map" />}
+      %{<img border="0" height="15" width="15" src="#{@url.path_image}/#{@icon.wmp}" alt="Concordance" />}
     end
     def para
       %{<img border="0" height="15" width="15" src="#{@url.path_image}/#{@icon.para}" alt="Segment" />}
@@ -864,7 +999,6 @@ module SiSU_Viz
     def home
     end
     def manifest_link                                                  #decide whether to hard link
-      #<a href="sisu_manifest.html">
       %{  <font face="#{@font.fonts}" size="2">
     #{@png.manifest}&nbsp;&nbsp;manifest&nbsp;
   </font> }
@@ -879,9 +1013,9 @@ module SiSU_Viz
     #{@png.doc}&nbsp;&nbsp;scroll&nbsp;
   </font> }
     end
-    def wmap
+    def concordance
       %{  <font face="#{@font.fonts}" size="2">
-    &nbsp;&nbsp;index&nbsp;
+    &nbsp;&nbsp;concordance&nbsp;
   </font> }
     end
     def previous
@@ -1587,41 +1721,7 @@ WOK
   </p>
 WOK
     end
-    def wayBetter_old
-<<WOK
-<table summary="" bgcolor="#ffffff" cellpadding="4" border="0" align="center">
-<tr align="center"><td align="center">
-  <p class="center">
-  <font color="#666666" size="2">
-    using 
-    <a href="http://www.ruby-lang.org/en/" alt="Ruby Programming Language">
-      Ruby
-    </a>
-  <br />
-    on the 
-    <a href="http://www.debian.org/" alt="Debian/Gnu/Linux">
-      Debian/Gnu/Linux
-    </a>
-  <br />
-    software infrastructure
-  <br />
-    think the usual GPL (or OSS) suspects
-  <br />
-  <br />
-    Get With the Future
-  <br />
-    &lt;&lt;
-    <a href="http://www.jus.uio.no/sisu/">
-      Way Better!
-    </a>
-    &gt;&gt;
-  </font>
-  </p>
-#{@table.close}
-#{@table.close}
-WOK
-    end
-    def wayBetter
+    def way_better
 <<WOK
   <p class="center">
   <font color="#666666" size="2">
@@ -1666,6 +1766,9 @@ WOK
 #{@table.close}
 WOK
     end
+    def wayBetter
+      way_better
+    end
   end
   class Credits
     def initialize
@@ -1703,7 +1806,7 @@ WOK
       %{  <center>
 <table align="center"bgcolor="#ffffff">
 <tr><td>
-  #{@widget.sisu}#{@widget.wayBetter}#{@widget.browsers}#{@widget.pdfviewers}
+  #{@widget.sisu}#{@widget.way_better}#{@widget.browsers}#{@widget.pdfviewers}
 </td></tr>
 </table>
 </center>}
@@ -1789,6 +1892,7 @@ information, Serialized Units - software for electronic texts,
 documents, books, digital libraries in plaintext, html, xhtml, XML,
 ODF (OpenDocument), LaTeX, pdf, SQL (PostgreSQL and SQLite), and
 for search</title>
+<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
 <meta name="dc.title" content=
 "SiSU information Structuring Universe - Simple - information Structuring Universe, SiSU is Structuring Unit programme &amp; program description, 2005" />
 <meta name="dc.creator" content="Ralph Amissah" />
@@ -1913,28 +2017,8 @@ outputs include: plaintext, html, xhtml, XML, ODF (OpenDocument), LaTeX, pdf, SQ
   man pages: 
 </p>
 <p>
-  <a href="http://www.jus.uio.no/sisu/man/sisu.1" target="_top" >
-    sisu.1
-  </a>
-</p>
-<p>
-  <a href="http://www.jus.uio.no/sisu/man/sisu.8" target="_top" >
-    sisu.8
-  </a>
-</p>
-<p>
-  <a href="http://www.jus.uio.no/sisu/man/sisu_examples.1" target="_top" >
-    sisu_examples.1
-  </a>
-</p>
-<p>
-  <a href="http://www.jus.uio.no/sisu/man/sisu_webrick.1" target="_top" >
-    sisu_webrick.1
-  </a>
-</p>
-<p>
-  <a href="http://www.jus.uio.no/sisu/man/sisu_vim.1" target="_top" >
-    sisu_vim.1
+  <a href="http://www.jus.uio.no/sisu/man" target="_top" >
+    sisu man pages
   </a>
 </p>
 <p class="tiny">
@@ -2022,8 +2106,8 @@ outputs include: plaintext, html, xhtml, XML, ODF (OpenDocument), LaTeX, pdf, SQ
 <p><b>(v)</b> use of Dublin Core and other meta-tags to permit the addition of some semantic information on documents, and making easy integration of rdf/rss feeds etc.,</p>
 <p><b>(vi)</b> creates organised directory/file structure for (file-system) output, easily mapped with its clearly defined structure, with all text objects numbered, you know in advance where in each document output type, a bit of text will be found (eg. from an sql search, you know where to go to find the prepared html output or pdf etc.)... there is more; easy directory management and document associations, the document preparation (sub-)directory may be used to determine output (sub-)directory, the skin used, and the sql database used,</p>
 <p><b>(vii)</b> search of document sets, at object/paragraph level, the relational database retains information on the document structure, and citation numbering makes it possible for example to present search matches as an index of documents and locations within the document where the match is found,</p>
-<p><b>(viii)</b> "word maps" rudimentary index, consisting of all the words in a document and their (text/ object) locations within the text, (and the possibility of adding vocabularies),</p>
-<p><b>(ix)</b> document content certification and comparison considerations: (a) the document and each object within it stamped with an md5 hash making it possible to easily check or guarantee that the substantive content of a document is unchanged, (b) version control, documents integrated with time based version control system, default RCS or CVS with use of $Id$ tag, which SiSU checks
+<p><b>(viii)</b> "Concordance file" wordmap, consisting of all the words in a document and their (text/ object) locations within the text, (and the possibility of adding vocabularies),</p>
+<p><b>(ix)</b> document content certification and comparison considerations: (a) the document and each object within it stamped with an md5 hash making it possible to easily check or guarantee that the substantive content of a document is unchanged, (b) version control, documents integrated with time based source control system, default RCS or CVS with use of $Id$ tag, which SiSU checks
 <p><b>(x)</b> SiSU's minimalist markup makes for meaningful "diffing" of the substantive content of markup-files,</p>
 <p><b>(xi)</b> easily skinnable, document appearance on a project/site wide, directory wide, or document instance level easily controlled/changed,</p>
 <p><b>(xii)</b> in many cases a regular expression may be used (once in the document header) to define all or part of a documents structure obviating or reducing the need to provide structural markup within the document,</p>
