@@ -5,8 +5,8 @@
    * http://www.jus.uio.no/sisu/SiSU/download
 
  * Description: xml (dom style) output processing
-   * $Id$
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005 Ralph Amissah
+
+ * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Ralph Amissah
 
  * License: GPL 2 or later
 
@@ -40,7 +40,7 @@
   *  Standard SiSU meta-markup syntax, and the
   *  Standard SiSU object citation numbering and system
   
-  © Ralph Amissah 1997, current 2005.
+  © Ralph Amissah 1997, current 2006.
   All Rights Reserved.
 
  * Ralph Amissah: ralph@amissah.com
@@ -49,48 +49,43 @@
  * Notes: tidy -xml dom.xml >> index.tidy
 =end
 module SiSU_Docbook
-  require "#{SiSU_lib}/defaults"
-  require "#{SiSU_lib}/param"
+  require SiSU_lib + '/defaults'
+  require SiSU_lib + '/param'
   include SiSU_Param
   include SiSU_Viz
-  require "#{SiSU_lib}/sysenv"
+  require SiSU_lib + '/sysenv'
   include SiSU_Env
-  require "#{SiSU_lib}/metaverse"
-  require "#{SiSU_lib}/common_xml"
-  require "#{SiSU_lib}/xml_format"
+  require SiSU_lib + '/metaverse'
+  require SiSU_lib + '/common_xml'
+  require SiSU_lib + '/xml_format'
   include SiSU_XML_format
   include SiSU_XML_character
-  require "#{SiSU_lib}/rexml"
+  require SiSU_lib + '/rexml'
   include SiSU_Rexml
   include SiSU_XML_character
   @@alt_id_count,@@tablehead,@@number_of_cols=0,0,0
   @@tablefoot=''
   class Source
-    def initialize(sf,cf)
-      @fns,@cf=sf,cf
-      @fnb=sf.gsub(/\.[_-]?sst$/,'')
-      unless sf =~/.+?\.[_-]?sst$/
-        puts "#{sf} not a processed file type"
-        jump
-      end
+    def initialize(opt)
+      @opt=opt
     end
     def read
       begin
-        @md=SiSU_Param::Parameters.new(@fns,@cf).get
-        @dir=SiSU_Env::Info_dir.new(@fns)
-        path=SiSU_Env::Info_dir.new(@fns).tell_output_path
-        loc=SiSU_Env::Info_dir.new(@fns).tell_output_location
-        tool=if @cf =~/[MV]/: "#{@dir.web_browser} #{loc}/#{@md.fnb}/#{@md.fn[:docbook]}\n\t#{@dir.xml_viewer} #{path}/#{@md.fnb}/#{@md.fn[:docbook]}"
-        elsif @cf =~/v/: "#{@dir.web_browser} #{loc}/#{@md.fnb}/#{@md.fn[:docbook]}"
+        @md=SiSU_Param::Parameters.new(@opt).get
+        @dir=SiSU_Env::Info_dir.new(@opt.fns)
+        path=SiSU_Env::Info_dir.new(@opt.fns).tell_output_path
+        loc=SiSU_Env::Info_dir.new(@opt.fns).tell_output_location
+        tool=if @opt.cmd =~/[MV]/: "#{@dir.web_browser} #{loc}/#{@md.fnb}/#{@md.fn[:docbook]}\n\t#{@dir.xml_viewer} #{path}/#{@md.fnb}/#{@md.fn[:docbook]}"
+        elsif @opt.cmd =~/v/: "#{@dir.web_browser} #{loc}/#{@md.fnb}/#{@md.fn[:docbook]}"
         else ''
         end
-        tell=SiSU_Screen::Ansi.new(@cf,'invert','XML DOM',tool)
-        tell.colorize unless @cf =~/q/
-        tell=SiSU_Screen::Ansi.new(@cf,@fns,"#{@dir.tell_output_path}/#{@md.fnb}/#{@md.fn[:docbook]}")
-        tell.flow if @cf =~/[MV]/
-        @metaverse_array=SiSU_Metaverse::Source.new(@fns,@cf).get # metaverse file drawn here
+        tell=SiSU_Screen::Ansi.new(@opt.cmd,'invert','XML DOM',tool)
+        tell.colorize unless @opt.cmd =~/q/
+        tell=SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@dir.tell_output_path}/#{@md.fnb}/#{@md.fn[:docbook]}")
+        tell.flow if @opt.cmd =~/[MV]/
+        @metaverse_array=SiSU_Metaverse::Source.new(@opt).get # metaverse file drawn here
         SiSU_Docbook::Source::Songsheet.new(@metaverse_array,@md,@dir).songsheet
-      rescue: SiSU_Errors::Info_error.new($!,$@,@cf,@fns).error
+      rescue: SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
         #file closed in songsheet
       end
@@ -103,9 +98,9 @@ module SiSU_Docbook
       def songsheet
         begin
           SiSU_Docbook::Source::Scroll.new(@data,@md).songsheet
-          SiSU_Docbook::Source::Tidy.new(@md,@dir).xml if @md.cf =~/[VM]/i # test wellformedness, comment out when not in use
-          SiSU_Rexml::Rexml.new(@md,@md.fn[:docbook],@md.cf).xml if @md.cf =~/M/ # test rexml parsing, comment out when not in use #debug
-        rescue: SiSU_Errors::Info_error.new($!,$@,@md.cf,@md.fns).error
+          SiSU_Docbook::Source::Tidy.new(@md,@dir).xml if @md.cmd =~/[VM]/i # test wellformedness, comment out when not in use
+          SiSU_Rexml::Rexml.new(@md,@md.fn[:docbook]).xml if @md.cmd =~/M/ # test rexml parsing, comment out when not in use #debug
+        rescue: SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
         ensure
         end
       end
@@ -124,13 +119,15 @@ module SiSU_Docbook
       Contents[2]='sect1'
       Contents[3]='sect2'
       @@xml=Hash.new
-      @@xml[:body],@@xml[:open],@@xml[:close],@@xml[:head],@@xml[:vc]=Array.new,Array.new,Array.new,Array.new,Array.new
-      require "#{SiSU_lib}/common_text"
+      @@xml[:body],@@xml[:open],@@xml[:close],@@xml[:head],@@xml[:sc]=Array.new,Array.new,Array.new,Array.new,Array.new
+      @@dp=nil
+      require SiSU_lib + '/common_text'
       include SiSU_text_utils
       def initialize(data='',md='')
         @data,@md=data,md
         @margin=SiSU_Viz::Margin.new
-        @regx=/^(?:(?:<:p[bn]>\s*)?\d~(?:(\S+))?\s+)?(.+?)\s*<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>$/ # 
+        @@dp ||=SiSU_Env::Info_dir.new.digest_pattern
+        @regx=/^(?:(?:<:p[bn]>\s*)?\d~(?:(\S+))?\s+)?(.+?)\s*<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>$/ # 
         @tab="\t"
         @char_enc=SiSU_XML_character::Encode.new
         @sys=SiSU_Env::System_call.new
@@ -143,7 +140,7 @@ module SiSU_Docbook
       end
     protected
       def xml_markup(para='')
-        para.gsub!(/~\{(\d+)\s+(.+?)\s*<[0-9a-f]{32}>\}~/, 
+        para.gsub!(/~\{(\d+)\s+(.+?)\s*<#{@@dp}>\}~/, 
           "<footnote><para>\\1 \\2</para></footnote> ")
       end
       def xml_head(meta='',verse='')
@@ -155,27 +152,27 @@ module SiSU_Docbook
 #{@tab}</#{meta}>
 WOK
       end
-      def xml_vc(md='')
-        vc=if @md.rc_info
+      def xml_sc(md='')
+        sc=if @md.sc_info
           <<WOK
-    <version_control>
-      <vc class="sourcefile">
-        #{@md.rc_filename}
-      </vc>
-      <vc class="number">
-        #{@md.rc_vnumber}
-      </vc>
-      <vc class="date">
-        #{@md.rc_date}
-      </vc>
-    </version_control>
+    <source_control>
+      <sc class="sourcefile">
+        #{@md.sc_filename}
+      </sc>
+      <sc class="number">
+        #{@md.sc_number}
+      </sc>
+      <sc class="date">
+        #{@md.sc_date}
+      </sc>
+    </source_control>
 WOK
         else ''
         end
-        @@xml[:vc]=vc   #<<<<WOK
+        @@xml[:sc]=sc   #<<<<WOK
 #WOK
       end
-      def xmlElement(lv='',ocn='',para='',hname='',tag='',xml_element='')
+      def xml_element(lv='',ocn='',para='',hname='',tag='',xml_element='')
         lv=lv.to_i
         n=lv - 1
         n1=lv
@@ -298,7 +295,7 @@ WOK
             @cont[3]=true
           end
         end
-        xmlElement(lv,ocn,para,hname,tag,xml_element)
+        xml_element(lv,ocn,para,hname,tag,xml_element)
         @level[lv]=true
         ((lv+1)..6).each { |x| @level[x]=false } 
       end
@@ -334,8 +331,8 @@ WOK
       end
       def markup
         data=@data
-        dir=SiSU_Env::Info_dir.new(@fns)
-        xml_vc(@md)
+        dir=SiSU_Env::Info_dir.new(@md.fns)
+        xml_sc(@md)
         @rcdc=false
         @level=Array.new
         @cont=Array.new 
@@ -345,10 +342,9 @@ WOK
         (4..6).each { |x| @xml_contents_close[x]='' } 
         data.each do |para|
           wordlist=para.scan(/\S+|\n/) #\n needed for tables, check though added 2005w17
-          #wordlist=para.scan(/\S+/)
           para=tidywords(wordlist).join(' ').strip
           para.gsub!(/<[-~]#>/, '')
-          para.gsub!(/<0;\w\d+;[um]\d+><[0-9a-f]{32}:[0-9a-f]{32}>/, '')
+          para.gsub!(/<0;\w\d+;[um]\d+><#{@@dp}:#{@@dp}>/, '')
           para.gsub!(/<:pb>\s*/, '')
           para.gsub!(/\{(\S+?\.(?:png|jpg)) .+?\}(?:(?:https?|ftp):\/\/\S+|image)/, 
             %{<imagedata fileref="#{dir.url_images_local}\/\\1"/>})
@@ -356,42 +352,20 @@ WOK
           para.gsub!(/&nbsp;/, ' ') #clean
           @char_enc.utf8(para) if @sys.locale =~/utf-?8/i #% utf8
           if para =~/^0~(\S+)\s+(.+?)$/ # for headers
-            case para
-            when /^0~(title)\s+(.+?)$/:             xml_head($1,$2)            #dc 1
-            when /^0~(subtitle)\s+(.+?)$/:          xml_head($1,$2)
-            when /^0~(creator|author)\s+(.+?)$/:    xml_head('author',$2)     #dc 2
-            when /^0~(subject)\s+(.+?)$/:           xml_head($1,$2)            #dc 3
-            when /^0~(description)\s+(.+?)$/:       xml_head($1,$2)            #dc 4
-            when /^0~(publisher)\s+(.+?)$/:         xml_head($1,$2)            #dc 5
-            when /^0~(contributor)\s+(.+?)$/:       xml_head($1,$2)            #dc 6
-            when /^0~(date)\s+(.+?)$/:              xml_head($1,$2)            #dc 7
-            when /^0~(date\.created)\s+(.+?)$/:     xml_head($1,$2)
-            when /^0~(date\.issued)\s+(.+?)$/:      xml_head($1,$2)
-            when /^0~(date\.available)\s+(.+?)$/:   xml_head($1,$2)
-            when /^0~(date\.valid)\s+(.+?)$/:       xml_head($1,$2)
-            when /^0~(date\.modified)\s+(.+?)$/:    xml_head($1,$2)
-            when /^0~(type)\s+(.+?)$/:              xml_head($1,$2)            #dc 8
-            when /^0~(format)\s+(.+?)$/:            xml_head($1,$2)            #dc 9
-            when /^0~(identifier)\s+(.+?)$/:        xml_head($1,$2)            #dc 10
-            when /^0~(source)\s+(.+?)$/:            xml_head($1,$2)            #dc 11
-            when /^0~(language)\s+(.+?)$/:          xml_head($1,$2)            #dc 12
-            when /^0~(relation)\s+(.+?)$/:          xml_head($1,$2)            #dc 13
-            when /^0~(coverage)\s+(.+?)$/:          xml_head($1,$2)            #dc 14
-            when /^0~(rights)\s+(.+?)$/:            xml_head($1,$2)            #dc 15
-            when /^0~(keywords)\s+(.+?)$/:          xml_head($1,$2)
-            when /^0~(copyright)\s+(.+?)$/:         xml_head($1,$2)
-            end
-          end
+            dc=SiSU_scan::Header_scan.new(@md,para).dublin
+            if dc: xml_head(dc[0],dc[1])
+	    end
+	  end
           @rcdc=true if @rcdc ==false and (para =~/~metadata/ or para =~/1~\s+Document Information/)
           if para !~/(^0~|<ENDNOTES>|<EOF>)/ 
-            if para =~/.+?<~\d+;(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>.*/
+            if para =~/.+?<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>.*/
               paranum=para[@regx, 3]  #/.+?<~(\d+?)>.*/.match(para)[1]
               @p_num=SiSU_XML_format::Paragraph_number.new(@md,paranum)
             end
             @sto=SiSU_text_parts::Split_text_object.new(@md,para).lev_segname_para_ocn
             ### problem in scroll, it appears tables are getting paragraph numbers
             unless @rcdc
-              m=/<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/
+              m=/<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/
               if para =~m
                 format_scroll=SiSU_XML_format::Format_scroll.new(@md,@sto.text) if @sto.format =~/i[12]|null/
                 case @sto.format
@@ -439,7 +413,7 @@ WOK
                 #      #para=@sto.lev_para_ocn.scrPara
                 #    end
                 else
-                  matched=/<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>$/mi.match(para)
+                  matched=/<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>$/mi.match(para)
                   stamp,ocn=matched[0],matched[1]
                   if para =~ /<:poem>/
                     para.gsub!(/#{stamp}/,'')
@@ -460,30 +434,30 @@ WOK
                     @@xml[:body] << "#{@tab*7}<para>#{para[@regx, 2]}</para>\n" if para[@regx, 2] # main text, contents, body KEEP ocn = #{para[@regx, 3]} == #{ocn}
                   end
                 end
-              elsif para =~/(Note|Endnotes?)/ and para !~/<~\d+;(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/
+              elsif para =~/(Note|Endnotes?)/ and para !~/<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/
                 #format_scroll=MonoSiSU.new('<br /><a name="notes">Note</a>')
                 #para=format_scroll.boldPara
-              elsif para =~/(MetaData)/ and para =~/<~\d+;[m]\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/ #debug 2003w46 add rc info
+              elsif para =~/(MetaData)/ and para =~/<~\d+;[m]\d+;\w\d+><#{@@dp}:#{@@dp}>/ #debug 2003w46 add rc info
                 format_scroll=Format_scroll.new(@md,'<br /><a name="metadata">MetaData</a>')
-                para=format_scroll.boldPara
-              elsif para =~/(Owner Details)/ and para !~/<~\d+;(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/
+                para=format_scroll.bold_para
+              elsif para =~/(Owner Details)/ and para !~/<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/
                 format_scroll=Format_scroll.new(@md,'<br /><a name="owner.details">Owner Details</a>')
-                @@xml[:owner_details]=format_scroll.boldPara
+                @@xml[:owner_details]=format_scroll.bold_para
                 para=''
               elsif para =~/(.*)<:#>(.*)/i
                 one, two=$1,$2
                 format_text=Format_text_object.new(one,two)
-                para=format_text.segNoParanum
+                para=format_text.seg_no_paranum
               end
               para='' if (para =~/<a name="n\d+">/ and para =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/) # -endnote
               if para =~/.*<:#>.*$/
                 para=case para
                 when /<:i1>/
                   format_text=Format_text_object.new(para,'')
-                  format_text.scrIndenocneNoParanum
+                  format_text.scr_inden_ocn_e_no_paranum
                 when /<:i2>/
                   format_text=Format_text_object.new(para,'')
-                  format_text.scrIndenocneNoParanum
+                  format_text.scr_inden_ocn_e_no_paranum
                 end
               end
               if para =~/<:center>/i
@@ -532,7 +506,7 @@ WOK
         #@@xml[:body] << "<body>\n"
       end
       def post
-        @@xml[:head] << @@xml[:vc]
+        @@xml[:head] << @@xml[:sc]
         @@xml[:head] << "</bookinfo>\n"
         #@@xml[:body] << "</body>\n"
         @@xml[:close] = "</book>\n"
@@ -583,14 +557,14 @@ WOK
       end
       def xml
         if @prog.tidy !=false
-          if @md.cf =~/[VM]/
-            tell=SiSU_Screen::Ansi.new(@md.cf,'invert','Using XML Tidy','check document structure')
-            tell.colorize unless @md.cf =~/q/
-            tell.greyOpen unless @md.cf =~/q/
+          if @md.cmd =~/[VM]/
+            tell=SiSU_Screen::Ansi.new(@md.cmd,'invert','Using XML Tidy','check document structure')
+            tell.colorize unless @md.cmd =~/q/
+            tell.grey_open unless @md.cmd =~/q/
             tidyfile='/dev/null' #don't want one or screen output, check for alternative flags
             tidy=SiSU_Env::System_call.new("#{@dir.data_o}/#{@md.fnb}/#{@md.fn[:docbook]}",tidyfile)
             tidy.well_formed?
-            tell.p_off unless @md.cf =~/q/
+            tell.p_off unless @md.cmd =~/q/
           end
         end
       end
