@@ -5,8 +5,8 @@
    * http://www.jus.uio.no/sisu/SiSU/download
 
  * Description: base formatting template for html generation
-   * $Id$
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005 Ralph Amissah
+
+ * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Ralph Amissah
 
  * License: GPL 2 or later
 
@@ -40,30 +40,30 @@
   *  Standard SiSU meta-markup syntax, and the
   *  Standard SiSU object citation numbering and system
   
-  © Ralph Amissah 1997, current 2005.
+  © Ralph Amissah 1997, current 2006.
   All Rights Reserved.
 
  * Ralph Amissah: ralph@amissah.com
                   ralph.amissah@gmail.com
 =end
 module SiSU_HTML_Format
-  require "#{SiSU_lib}/param"
+  require SiSU_lib + '/param'
   include SiSU_Param
   include SiSU_Viz
   #include SiSU_HTML_Format
-  require "#{SiSU_lib}/common_xml"
+  require SiSU_lib + '/common_xml'
   include SiSU_XML_tags
-  require "#{SiSU_lib}/common_text"
+  require SiSU_lib + '/common_text'
   include SiSU_text_utils
   class Paragraph_number
     def initialize(md,paranum)
       @md=md
-      @paranum=paranum[/(\d+)/im, 1]
+      @paranum=paranum[/(\d+)/im,1]
       @paranum ||=''
       @paranum='' if @paranum =~/^0$/
     end
     def ocn_display
-      ocn_class=if @md.cf =~/[phH]\S*0/: 'ocn_off'
+      ocn_class=if @md.cmd =~/[phH]\S*0/: 'ocn_off'
       else                               'ocn'
       end
       @paranum.gsub(/^(\d+|)$/,
@@ -115,44 +115,16 @@ module SiSU_HTML_Format
       %{  <p #{@p_num.id} align="justify">#{@p_num.name}
   <font #{@font.small} #{@font.color} #{@font.face}>} # keep but not used?
     end
-    def fontTiny
+    def font_tiny
       %{<font #{@font.tiny} #{@font.face}>}
     end
-    def fontSmall
+    def font_small
       %{<font #{@font.small} #{@font.face}>}
     end
     def header_
       %{  <p #{@p_num.id} align="center">#{@p_num.name}
   <font #@font color="#@color" #{@font.face}>}
     end
-    def header_title
-      font,color=@font.size_title,'#0000ff'
-      header_
-    end
-    def header_1
-      font,color=@font.size_header_1,'#000000'
-      header_
-    end
-    def header_2
-      font,color=@font.size_header_2,'#000000'
-      header_
-    end
-    def header_3
-      font,color=@font.size_header_3,'#990000'
-      header_
-    end
-    def header_4
-      font,color=@font.size_header_4,'#ff0000'
-      header_
-    end
-    def header_5
-      font,color=@font.size_header_5,'#ff0000'
-      header_
-    end
-    def header_6
-      font,color=@font.size_header_6,'#ff0000'
-      header_
-    end
   end
   class Head_information
     #attr_accessor
@@ -193,7 +165,7 @@ module SiSU_HTML_Format
       @metalink='#metadata'
       @tocband_scroll,@tocband_segtoc=nil,nil
     end
-    def docType
+    def doc_type
       %{<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
 "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">\n}
@@ -206,20 +178,20 @@ module SiSU_HTML_Format
     def seg_head_escript #embedded script in this case PHP 
       # %{<p>PHP or other embedded script for object persistence may go HERE</p>}
     end
-    def tableClose
+    def table_close
       %{  </font>
 #{@table.close}}
     end
-    def buttonsHome
-      %{<!-- home and index buttons --!>
+    def buttons_home
+      %{<!- home and index buttons -!>
   #{@banner.home_and_index_buttons}
-<!-- home and index buttons --!>}
+<!- home and index buttons -!>}
     end
     def copyat
-      %{copy @
+      %{#{@paragraph.heading_1_center}copy @
   <a href="#{@url.home}" #{@js.home}>
     #{@txt.home}
-  </a>}
+  </a></h1>}
     end
   end
   class Head_toc < Head_information
@@ -238,6 +210,7 @@ WOK
       else ''
       end
       %{<table summary="toc scroll navigation band">
+<tr>
 <td width="20%">
   &nbsp;
 </td></tr>
@@ -259,6 +232,7 @@ WOK
       #{@nav_png.nxt}
     </a>} if @md.firstseg =~/\S+/
       %{<table summary="toc segment navigation band">
+<tr>
 <td width="20%">&nbsp;</td>
 </tr></table>
 <table summary="table of contents" id="toc" bgcolor=#{@color.band1}>
@@ -273,6 +247,16 @@ WOK
 #{@table.close}
 <p />}
     end
+    def concordance_link(text)
+      if @md.concord_make
+  %{<font size=2>
+    <a href="#{@md.fn[:concordance]}" target="_top" #{@js.concordance}>
+      #{text}
+    </a>
+  </font>}
+      else ''
+      end
+    end
     def make_scroll_pdf
       pdf=if @md.programs[:pdf]
         %{
@@ -291,6 +275,7 @@ WOK
 </td>}
       else ''
       end
+      concord=concordance_link(@nav_txt.concordance)
       %{<table summary="toc scroll with pdf" border="0" cellpadding="3" cellspacing="0">
 <tr>
 <td align="center" bgcolor=#{@color.band2} border="0">
@@ -301,11 +286,7 @@ WOK
   #{@nav_txt.doc_link}
 </td>#{pdf}
 <td align="center" bgcolor=#{@color.band2}>
-  <font size=2>
-    <a href="#{@md.fn[:wmap]}" target="_top" #{@js.wmap}>
-      #{@nav_txt.wmap}
-    </a>
-  </font>
+   #{concord}
 #{@table.close}}
     end
     def make_seg_pdf
@@ -325,17 +306,14 @@ WOK
 </td>}
       else ''
       end
+      concord=concordance_link(@nav_txt.concordance)
       %{<table summary="toc segment with pdf" border="0" cellpadding="3" cellspacing="0">
 <tr>
 <td align="center" bgcolor=#{@color.band2}>
   #{@nav_txt.toc_link} 
 </td></td>#{pdf}
 <td align="center" bgcolor=#{@color.band2}>
-  <font size=2>
-    <a href="#{@md.fn[:wmap]}" target="_top" #{@js.wmap}>
-      #{@nav_txt.wmap}
-    </a>
-  </font>
+   #{concord}
 #{@table.close}}
     end
     def make_seg_scroll_pdf
@@ -355,6 +333,7 @@ WOK
 </td>}
       else ''
       end
+      concord=concordance_link(@nav_txt.concordance)
       %{<table summary="toc segment and scroll with pdf" border="0" cellpadding="3" cellspacing="0">
 <tr>
 <td align="center" bgcolor=#{@color.band2} border="0">
@@ -370,11 +349,7 @@ WOK
   </a>
 </td>#{pdf}
 <td align="center" bgcolor=#{@color.band2}>
-  <font size=2>
-    <a href="#{@md.fn[:wmap]}" target="_top" #{@js.wmap}>
-      #{@nav_txt.wmap}
-    </a>
-  </font>
+   #{concord}
 #{@table.close}}
     end
     def make_scroll_seg_pdf
@@ -415,28 +390,26 @@ WOK
 </td>
 }
       end
+      concord=concordance_link(@nav_txt.concordance)
       %{<table summary="toc scroll and segment with pdf" border="0" cellpadding="3" cellspacing="0">
 <tr>
   #{manifest}
   #{seg}
   #{scroll}#{pdf}
 <td align="center" bgcolor=#{@color.band2}>
-  <font size=2>
-    <a href="#{@md.fn[:wmap]}" target="_top" #{@js.wmap}>
-      #{@nav_txt.wmap}
-    </a>
-  </font>
+  #{concord}
 #{@table.close}}
     end
     def head
-      %{#{docType}
+      %{#{doc_type}
 <head>
   <title>
     #{@md.html_title}
   </title>
+  <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
   #{@rdf.rdftoc}
   #{@rdf.metatag_html}
-  #{@font.cssTable_file}
+  #{@font.css_table_file}
 </head>
 #{@color.body}
   <a name="top" id="top"></a>
@@ -485,8 +458,8 @@ WOK
     </a>
   </li>#{scroll}#{pdf}
   <li class="ref">
-    <a href="./wordmap" alt="wordmap, rudimentary index" target="_top">
-      wordmap
+    <a href="./concordance" alt="concordance, rudimentary index" target="_top">
+      concordance
     </a>
   </li>
   </ul>
@@ -496,10 +469,13 @@ WOK
       #document_version_hold
     end
     def links_guide_vertical_open
+      url=if defined? @url.hp: @url.hp
+      else @url.home
+      end
       %{<div id="vertical_links">
   <ul id="vertical">
   <li class="refbold">
-    <a href="#{@url.home}" #{@js.home}>
+    <a href="#{url}" #{@js.home}>
       #{@txt.hp}
     </a>
   </li>
@@ -511,13 +487,16 @@ WOK
       Manifest
     </a>
   </li>
-<!-- quick ref --!>}
+<!- quick ref -!>}
     end
     def links_guide_horizontal_open
+      url=if defined? @url.hp: @url.hp
+      else @url.home
+      end
       %{<div id="horizontal_links">
   <ul id="horizontal">
   <li class="refbold">
-    <a href="#{@url.home}" #{@js.home}>
+    <a href="#{url}" #{@js.home}>
       #{@txt.hp}
     </a>
   </li>
@@ -529,7 +508,7 @@ WOK
       Manifest
     </a>
   </li>
-<!-- quick ref --!>}
+<!- quick ref -!>}
     end
     def links_guide_open(type='horizontal')
       if type=='vertical': links_guide_vertical_open
@@ -559,15 +538,18 @@ WOK
 </div>}
       end
       %{ #{insert}
-<!-- quick ref --!>}
+<!- quick ref -!>}
     end
     def links_guide_open_old
+      url=if defined? @url.hp: @url.hp
+      else @url.home
+      end
       %{  <br />
   #{@banner.open_blue}
   #{@banner.blueband}
   <br />
   <p class="bigref">
-    <a href="#{@url.home}#@sfx" #{@js.home}>
+    <a href="#{url}#@sfx" #{@js.home}>
       #{@png.hp_nav}
       #{@txt.hp}
     </a>
@@ -575,13 +557,13 @@ WOK
   <p class="quickref">
      Quick Ref.:
   </p>
-<!-- quick ref --!>}
+<!- quick ref -!>}
     end
     def links_guide_close_old
       insert=''
       insert=@banner.home_guide if @md.sfx_src =~/lm?/
       %{ #{insert}
-<!-- quick ref --!>
+<!- quick ref -!>
 #{@banner.blueband}
 #{@banner.close_blue}
 <br />}
@@ -589,7 +571,7 @@ WOK
     def prefix_a
     end
     def rights
-      rights=@md.dc_rights.gsub(/^\s*Copyright\s+/, '<sup>&copy;</sup>&nbsp;')
+      rights=@md.dc_rights.gsub(/^\s*Copyright\s+/,'<sup>&copy;</sup>&nbsp;')
       %{<table summery="copyright">
 <tr>
 <td width=10%>&nbsp;</td>
@@ -615,58 +597,47 @@ WOK
       %{<center>
 #{@md.icon}
 </center>
-#{@banner.instrument_cover_band_scr}
-#{@paragraph.header_1}}
+#{@banner.instrument_cover_band_scr}}
     end
     def seg_head_title_banner_open
       %{<center>
   #{@md.icon}
 </center>
-#{@banner.instrument_cover_band_seg}
-  #{@paragraph.header_1}}
+#{@banner.instrument_cover_band_seg}}
     end
     def make_scroll
+      concord=concordance_link(@nav_txt.concordance)
       %{<table summary="toc scroll" border="0" cellpadding="3" cellspacing="0">
 <tr><td align="center" bgcolor="white" border="0">
   #{@nav_txt.doc_link}
 </td>
 <td align="center" bgcolor="white">
-  <font size=2>
-    <a href="../#{@md.fnb}/#{@md.fn[:wmap]}" target="_top" #{@js.wmap}>
-      #{@nav_txt.wmap}
-    </a>
-  </font>
+   #{concord}
 #{@table.close}}
     end
     def make_seg
+      concord=concordance_link(@nav_txt.concordance)
       %{<table summary="toc segment" border="0" cellpadding="3" cellspacing="0">
 <tr><td align="center" bgcolor="white">
   #{@nav_txt.toc_link}
 </td>
 <td align="center" bgcolor="white">
   <font size=2>
-    <a href="#{@md.fn[:wmap]}" target="_top" #{@js.wmap}>
-      #{@nav_txt.wmap}
-    </a>
-  </font>
+   #{concord}
 #{@table.close}}
     end
-    def wordmap #check structure
+    def concordance #check structure
+      concord=concordance_link(@nav_txt.concordance)
       %{#{@margin.txt_3}
-  #{@paragraph.fontSmall}
-    <a href="./#{@md.fn[:wmap]}" #{@js.wmap}>
-      #{@nav_txt.wmap}
-      <font size="1" color="#777777">
-        &nbsp;&nbsp;&nbsp;
-      </font>
-    </a>
+  #{@paragraph.font_small}
+   #{concord}
     </font> 
 #{@table.close}}
     end
     def metadata
       %{#{@margin.txt_3}
-#{@paragraph.fontSmall}
-  <a href="#@metalink" #{@js.wmap}>
+#{@paragraph.font_small}
+  <a href="#@metalink" #{@js.metalink}>
     <i>MetaData</i>
     <font size="1" color="#777777">
       &nbsp;&nbsp;&nbsp;
@@ -738,7 +709,7 @@ WOK
     end
     def toc_owner_details
       %{#{@margin.txt_3}
-#{@paragraph.fontSmall}
+#{@paragraph.font_small}
   <a href="#owner.details">
     Owner Details
     <font size="1" color="#777777">
@@ -767,11 +738,10 @@ WOK
     end
     def toc_endnote
       %{#{@margin.txt_3}
-#{@paragraph.fontSmall}
+#{@paragraph.font_small}
   <a href="#endnotes">
     Endnotes
   </a>
-  </font>
 #{@table.close}}
     end
     def title_endnote
@@ -780,7 +750,6 @@ WOK
   <br />
   <a name="endnotes" id="endnotes"></a>
   <b>Endnotes</b>
-  </font>
 #{@margin.num}
   &nbsp;
 #{@table.close}}
@@ -824,15 +793,16 @@ WOK
       super(md)
     end
     def head
-      %{#{docType}
+      %{#{doc_type}
 <head>
   <title>
     #{@seg_name_html[@seg_name_html_tracker]} - 
     #{@md.html_title}
   </title>
+<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
 #{@rdf.rdfseg}
 #{@rdf.metatag_html}
-#{@font.cssTable_file}
+#{@font.css_table_file}
 </head>
 #{@color.body}
 <a name="top" id="top"></a>
@@ -841,26 +811,6 @@ WOK
 #{@js.top}} 
     end
     def title_banner(title,subtitle,creator)
-#      %{#{@banner.instrument_cover_band_seg}
-##{@paragraph.header_1}
-#  #{title}
-#  </font>
-#  </p>
-#  <p align="center">
-#    #{@paragraph.fontSmall}
-#    #{subtitle}
-#  </font>
-#  </p>
-#  <p align="center">
-#    #{creator}
-#  </p>
-#  <p align="center">
-#    copy @
-#    <a href="#{@url.home}" #{@js.home}>
-#      <b>#{@txt.home}</b>
-#    </a>
-#  </p>
-##{@table.close}}
     end
     def dot_control_pre_next
       %{<table summary="segment hidden control pre and next" width="100%" border="0" cellpadding="0" bgcolor=#{@color.grey_pale} align="center">
@@ -933,7 +883,17 @@ WOK
     def toc_pre2
       toc_nav(true,false,2).dup
     end
-    def doc_types #used in segNavBand ###
+    def concordance_link(text)
+      if @md.concord_make
+  %{<font size=2>
+    <a href="#{@md.fn[:concordance]}" target="_top" #{@js.concordance}>
+      #{text}
+    </a>
+  </font>}
+      else ''
+      end
+    end
+    def doc_types #used in seg_nav_band ###
       scroll=seg=''
       pdf=if @md.programs[:pdf]
         %{<td align="center" bgcolor=#{@color.band2}>
@@ -953,10 +913,7 @@ WOK
       end
       dir=SiSU_Env::Info_dir.new(@md.fns)
       sum='manifest'
-      #sum=if dir.webserv_url =~/\S+/
-      #  "#{dir.webserv_url}/#{@md.fnb}/sisu_manifest.html"
-      #else 'sisu_manifest.html'
-      #end
+      concord=concordance_link(@nav_txt.concordance)
       if @md.fns =~ /\.[_-]?sst$/
         scroll=%{<td align="center" bgcolor=#{@color.band2}>
   <a href="#{@md.fn[:doc]}" target="_top" #{@js.doc}>
@@ -972,20 +929,16 @@ WOK
 </td>}
       end
       %{
-<table summary="segment navigation available documents types: toc,doc,pdf,wordmap" border="0" cellpadding="3" cellspacing="0">
+<table summary="segment navigation available documents types: toc,doc,pdf,concordance" border="0" cellpadding="3" cellspacing="0">
 <tr>
   #{seg}
   #{scroll}
   #{pdf}
 <td align="center" bgcolor=#{@color.band2}>
-  <font size=2>
-    <a href="#{@md.fn[:wmap]}" target="_top" #{@js.wmap}>
-      #{@nav_txt.wmap}
-    </a>
-  </font>
+  #{concord}
 #{@table.close}}
     end
-    def toc_pre_next3 #used with segDocTypes in segNavBand #with pdf & other doc types #knxjs
+    def toc_pre_next3 #used with seg_doc_types in seg_nav_band #with pdf & other doc types #knxjs
       %{<table summary="segment navigation pre/next" border="0" cellpadding="3" cellspacing="0">
 <tr><td align="center" bgcolor=#{@color.band1}>
   <a href="#{@md.fnl[:pre]}#{@seg_name_html[@seg_name_html_tracker-1]}#{@md.fnl[:mid]}#@sfx#{@md.fnl[:post]}" target="_top" #{@js.prev}>
@@ -1003,7 +956,7 @@ WOK
   </a>
 #{@table.close}} 
     end
-    def toc_next3 #used with segDocTypes in segNavBand #with pdf & other doc types #knxjs
+    def toc_next3 #used with seg_doc_types in seg_nav_band #with pdf & other doc types #knxjs
       %{<table summary="segment navigation next" border="0" cellpadding="3" cellspacing="0">
 <tr>
 <td align="center" bgcolor=#{@color.band1}>
@@ -1017,7 +970,7 @@ WOK
   </a>
 #{@table.close}} 
     end
-    def toc_pre3 #used with segDocTypes in segNavBand #with pdf and other doc types #knxjs
+    def toc_pre3 #used with seg_doc_types in seg_nav_band #with pdf and other doc types #knxjs
     # note endnotes is now two back, with insertion between end of text and metadata, but what happens where no endnote?
       %{<table summary="segment navigation pre" border="0" cellpadding="3" cellspacing="0">
 <tr><td align="center" bgcolor=#{@color.band1}>
@@ -1048,7 +1001,7 @@ WOK
   </h4>
 #{@table.close}
 #{table_top_control}
-#{@paragraph.header_1}
+#{@paragraph.heading_1}
 <b><i>Endnotes</i></b></font></p>}
     end
     def navigation_table
@@ -1116,13 +1069,14 @@ WOK
 </body>
 </html>}
     end
-    def navigation_band(segtocband, seg_table_top_control)
+    def navigation_band(segtocband,seg_table_top_control)
       %{<table summary="segment navigation band" bgcolor=#{@color.band1} width="100%">
 <tr><td width="10%" align="left">
 #{@banner.band}
 </td>
 <td align="left">
 <table summary="segment hidden control pre and next" width="100%" border="0" cellpadding="0" bgcolor=#{@color.band1} align="center">
+<tr>
 <td align="left" bgcolor="white">
  &nbsp;<a href="#{@md.fn[:manifest]}" target="_top">
 #{@nav_txt.manifest_link}</a>
@@ -1155,14 +1109,16 @@ WOK
     @@font=SiSU_Viz::Font.new
     @@table=SiSU_Viz::Table.new
     @@color=SiSU_Viz::Color.new
+    @@dp=nil
     attr_accessor :md,:one,:two,:three,:parablock,:table,:link,:linkname,:format,:paranum,:p_num,:para_id,:headname,:margin,:paragraph,:table,:banner,:url,:icon,:font,:one_stripped
     def initialize(md='',*txt)
-      txt[0].gsub!(/\.(html|pdf|php)/, '') if txt[0] =~/\.\.\/\S+/
+      txt[0].gsub!(/\.(html|pdf|php)/,'') if txt[0] =~/\.\.\/\S+/
       @md,@one,@two,@three=md,txt[0],txt[1],txt[2]
       rgx=/[1-6-]~/
-      @one_stripped=@one.gsub(rgx, '') if @one =~rgx
-      rgx=/~\{\d+\s+(.+?)<[0-9a-f]{32}>\}~/ #problem introduced
-      @one_stripped=@one.gsub(rgx, "\\1") if @one =~rgx #problem introduced
+      @one_stripped=@one.gsub(rgx,'') if @one =~rgx
+      @@dp ||=SiSU_Env::Info_dir.new.digest_pattern
+      rgx=/~\{[\d*+]+\s+(.+?)<#{@@dp}>\}~/ #problem introduced
+      @one_stripped=@one.gsub(rgx,'\1') if @one =~rgx #problem introduced
       @link,@linkname=txt[0],txt[1]
       @format,parablock=txt[0],txt[1]
       @parablock=if parablock=~/\S+/
@@ -1180,8 +1136,10 @@ WOK
       end
       @headname=''
       if @format =~ /\d~(\S+)/im
-        headname=$1 #format[/\d~(\S+)/im, 1]
-        @headname=%{<a name="h#{headname}" id="h#{headname}"></a>} # unless headname.nil?
+        headname=$1 #format[/\d~(\S+)/im,1]
+        @headname=if headname =~/^[a-zA-Z]/: %{<a name="#{headname}" id="#{headname}"></a>} #consider: h_#{headname}
+        else %{<a name="h#{headname}" id="h#{headname}"></a>}
+        end
       end
       @margin=@@margin       #SiSU_Viz::Margin.new
       @paragraph=@@paragraph #SiSU_Viz::Paragraph.new
@@ -1192,7 +1150,7 @@ WOK
       @font=@@font           #SiSU_Viz::Font.new
       @table=@@table         #SiSU_Viz::Table.new
       @color=@@color         #SiSU_Viz::Color.new
-      #file_base=@one.gsub(/\.(html|pdf|php)/, '') if @one =~/\.\.\/\S+/
+      #file_base=@one.gsub(/\.(html|pdf|php)/,'') if @one =~/\.\.\/\S+/
       #@link,@linkname=file_base,@two
     end
     def para_form                                                                # regular paragraphs shaped here
@@ -1263,15 +1221,15 @@ WOK
     def gsub_body
       case @one
       when /^(?:<:i[12]>\s*)?\((i+|iv|v|vi+|ix|x|xi+)\)/
-        @one.gsub!(/^\((i+|iv|v|vi+|ix|x|xi+)\)/, %{<b>(\\1)</b>})
-        @one.gsub!(/^(<:i[12]>)\s*\((i+|iv|v|vi+|ix|x|xi+)\)/, %{\\1<b>(\\2)</b>})
+        @one.gsub!(/^\((i+|iv|v|vi+|ix|x|xi+)\)/,%{<b>(\\1)</b>})
+        @one.gsub!(/^(<:i[12]>)\s*\((i+|iv|v|vi+|ix|x|xi+)\)/,%{\\1<b>(\\2)</b>})
       when /^(?:<:i[12]>\s*)?\(?(\d|[a-z])+\)/
-        @one.gsub!(/^\((\d+|[a-z])+\)/, %{<b>(\\1)</b>})
-        @one.gsub!(/^(<:i[12]>)\s*\((\d+|[a-z])+\)/, %{\\1<b>(\\2)</b>})
+        @one.gsub!(/^\((\d+|[a-z])+\)/,%{<b>(\\1)</b>})
+        @one.gsub!(/^(<:i[12]>)\s*\((\d+|[a-z])+\)/,%{\\1<b>(\\2)</b>})
       when /^\s*\d{1,3}\.\s/
-        @one.gsub!(/^\s*(\d+\.)/, %{<b>\\1</b>})
+        @one.gsub!(/^\s*(\d+\.)/,%{<b>\\1</b>})
       when /^\s*[A-Z]\.\s/
-        @one.gsub!(/^\s*([A-Z]\.)/, %{<b>\\1</b>})
+        @one.gsub!(/^\s*([A-Z]\.)/,%{<b>\\1</b>})
       end
     end
     def bold_para
