@@ -5,8 +5,8 @@
    * http://www.jus.uio.no/sisu/SiSU/download
 
  * Description: document summary processing, available outputs and metadata
-   * $Id$
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005 Ralph Amissah
+
+ * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Ralph Amissah
 
  * License: GPL 2 or later
 
@@ -40,7 +40,7 @@
   *  Standard SiSU meta-markup syntax, and the
   *  Standard SiSU object citation numbering and system
   
-  © Ralph Amissah 1997, current 2005.
+  © Ralph Amissah 1997, current 2006.
   All Rights Reserved.
 
  * Notes: tidy -ascii index.xml >> index.tidy
@@ -49,45 +49,53 @@
                   ralph.amissah@gmail.com
 =end
 module SiSU_Manifest
-  require "#{SiSU_lib}/sysenv"
+  require SiSU_lib + '/sysenv'
+  require SiSU_lib + '/babel'
   include SiSU_Env
   include SiSU_Param
   include SiSU_Viz
   class Source
-    def initialize(fns,cf)
-      @fns,@cf=fns,cf
-      @md=SiSU_Param::Parameters.new(@fns,@cf).get
+    def initialize(opt)
+      @opt=opt
+      @md=SiSU_Param::Parameters.new(@opt).get
       @fnb=@md.fnb
+      l=SiSU_Env::Standardise_language.new.file_to_language(@opt.fns)
+      @doc_language=l[:l]
     end
     def read
       begin
-        @md=SiSU_Param::Parameters.new(@fns,@cf).get
-        @dir=SiSU_Env::Info_dir.new(@fns)
-        path=SiSU_Env::Info_dir.new(@fns)
-        xbrowser=@dir.web_browser
-        browser=@dir.console_web_browser
+        @md=SiSU_Param::Parameters.new(@opt).get
+        @env=SiSU_Env::Info_dir.new(@opt.fns)
+        path=SiSU_Env::Info_dir.new(@opt.fns)
+        xbrowser=@env.web_browser
+        browser=@env.console_web_browser
         webserv_url=path.tell_output_location
         url_html="#{webserv_url}/#{@md.fnb}/#{@md.fn[:manifest]}"
-        tell=SiSU_Screen::Ansi.new(@cf,'Manifest',"#{xbrowser} #{url_html}")
-        tell.greenHiBlue unless @cf =~/q/
-        tell=SiSU_Screen::Ansi.new(@cf,"#{browser} #{url_html}")
-        tell.grey_tab if @cf =~/v/i
-        Output_Info.new(@md,@fns).check_output
-      rescue: SiSU_Errors::Info_error.new($!,$@,@cf,@fns).error
+        tell=SiSU_Screen::Ansi.new(@opt.cmd,'Manifest',"#{xbrowser} #{url_html}")
+        tell.green_hi_blue unless @opt.cmd =~/q/
+        tell=SiSU_Screen::Ansi.new(@opt.cmd,"#{browser} #{url_html}")
+        tell.grey_tab if @opt.cmd =~/v/i
+        Output_Info.new(@md).check_output
+      rescue: SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
       end
     end
     private
     class Output_Info <Source
-      def initialize(md,fns)
+      def initialize(md)
         @manifest=Hash.new
         @manifest[:txt],@manifest[:html]=Array.new,Array.new
-        @md,@fns=md,fns
-        @dir=SiSU_Env::Info_dir.new(fns)
+        @md,@fns=md
+        @env=SiSU_Env::Info_dir.new(@md.fns)
         @fnb=@md.fnb
-        out=@dir.data_o
-        @base_url="#{@dir.output_links_path[:url_root]}/#@fnb"
+        out=@env.data_o
+        @base_url="#{@env.output_links_path[:url_root]}/#@fnb"
         @base_path="#{out}/#@fnb"
+        @@dg ||=SiSU_Env::Info_dir.new.digest
+        @dg=@@dg
+        l=SiSU_Env::Standardise_language.new.file_to_language(@md.fns)
+        @language=l[:l]
+        @translate=SiSU_Translate::Source.new(@md,@language)
       end
       def output
         SiSU_Env::SiSU_file.new(@md).mkdir
@@ -97,7 +105,6 @@ module SiSU_Manifest
         end
       end
       def summarize(id,file)
-        #p "#@base_url/#{file}"
         size=(File.size("#{@base_path}/#{file}")/1024.00).to_s
         kb=/([0-9]+\.[0-9]{0,1})/im.match(size)[1]
         @manifest[:txt] << "#{file} #{id} #{kb}\n"
@@ -105,30 +112,32 @@ module SiSU_Manifest
       end
       def summarize_source(id,file)
         sys=SiSU_Env::System_call.new
-        dgst=sys.md5("#{@base_path}/#{file}")
-        tell=SiSU_Screen::Ansi.new(@md.cf,"#{dgst[1]} #{file}")
-        tell.warn if @md.cf =~/[vVM]/
+        dgst =if @dg =~/^sha(?:2|256)$/: sys.sha256("#{@base_path}/#{file}")
+        else                             sys.md5("#{@base_path}/#{file}")
+        end
+        tell=SiSU_Screen::Ansi.new(@md.cmd,"#{dgst[1]} #{file}")
+        tell.warn if @md.cmd =~/[vVM]/
         size=(File.size("#{@base_path}/#{file}")/1024.00).to_s
         kb=/([0-9]+\.[0-9]{0,1})/im.match(size)[1]
         @manifest[:txt] << "#{file} #{id} #{kb}\n"
         @manifest[:html] << %{<tr><th class="left"><p class="tiny">#{id}:</p> <p class="norm"><a href="#{file}">#{file}</a></p><p class="tiny"><a href="#@base_url/#{file}">#@base_url/#{file}</a></p></th><td class="right"><p class="tiny">#{dgst[1]}</p></td><td class="right"><p class="right">#{kb}</p></td></tr>\n}
       end
       def languages(id,file)
-        #SiSU_Env::Env_call
-        flv=@dir.published_manifests?(@base_path)
+        flv=@env.published_manifests?(@base_path)
         @manifest[:html] << %{<tr><th class="left"><p class="bold"><p class="bold">\n}
         flv.each do |l|
-          @manifest[:txt] << "#{l[:m]} #{l[:l]}\n"
-          @manifest[:html] << %{<a href="#{l[:m]}">#{l[:l]}</a>&nbsp;&nbsp;&nbsp; }
+          lang=SiSU_Translate::Source.new(@md,@language,l[:l]).language_list
+          @manifest[:txt] << "#{l[:m]} #{lang}\n"
+          @manifest[:html] << %{<a href="#{l[:m]}">#{lang}</a>&nbsp;&nbsp;&nbsp; }
         end
         @manifest[:html] << %{</p></th></tr>\n}
       end
       def published_languages(id,file)
-        #SiSU_Env::Env_call
-        flv=@dir.published_manifests?(@base_path)
+        flv=@env.published_manifests?(@base_path)
         flv.each do |l|
-          @manifest[:txt] << "#{l[:m]} #{l[:l]}\n"
-          @manifest[:html] << %{<tr><th class="left"><p class="bold"><a href="#{l[:m]}">#{l[:l]}</a></p></th><td><p class="norm">#{l[:l]}</p><p class="tiny"><a href="#@base_url/#{l[:m]}">#@base_url/#{l[:m]}</a></p></td><td class="right"><p class="right">&nbsp;</p></td></tr>\n}
+          lang=SiSU_Translate::Source.new(@md,@language,l[:l]).language_list
+          @manifest[:txt] << "#{l[:m]} #{lang}\n"
+          @manifest[:html] << %{<tr><th class="left"><p class="bold"><a href="#{l[:m]}">#{lang}</a></p></th><td><p class="norm">#{lang}</p><p class="tiny"><a href="#@base_url/#{l[:m]}">#@base_url/#{l[:m]}</a></p></td><td class="right"><p class="right">&nbsp;</p></td></tr>\n}
         end
       end
       def metadata(id,info)
@@ -136,7 +145,7 @@ module SiSU_Manifest
       end
       def links(url,lnk,target)
         static=if url =~/^\.\//: url.gsub(/^\.(\.)?/,@base_url)
-        elsif url =~/^\.\.\//:   url.gsub(/^\.(\.)?/,@dir.output_links_path[:url_root])
+        elsif url =~/^\.\.\//:   url.gsub(/^\.(\.)?/,@env.output_links_path[:url_root])
         else                     url                            
         end
         @manifest[:html] << %{<tr><th class="left"><p class="norm"><a href="#{url}">#{lnk}</a></p><p class="tiny"><a href="#{static}">#{static}</a></p></th></tr>\n}
@@ -163,7 +172,7 @@ module SiSU_Manifest
           summarize(id,file)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:odf]}")==true
-          id,file='ODF (Open Document Format)',@md.fn[:odf]
+          id,file='ODF:ODT (Open Document Format)',@md.fn[:odf]
           summarize(id,file)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:pdf_p]}")==true
@@ -175,125 +184,127 @@ module SiSU_Manifest
           summarize(id,file)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:plain]}")==true
-        if    @md.cf =~/a/: id,file='plaintext Unix (UTF-8) (footnotes)',@md.fn[:plain]
-        elsif @md.cf =~/e/: id,file='plaintext Unix (UTF-8) (endnotes)',@md.fn[:plain]
-        elsif @md.cf =~/A/: id,file='plaintext dos (UTF-8) (footnotes)',@md.fn[:plain]
-        elsif @md.cf =~/E/: id,file='plaintext dos (UTF-8) (endnotes)',@md.fn[:plain]
+        if    @md.cmd =~/a/: id,file='plaintext Unix (UTF-8) (footnotes)',@md.fn[:plain]
+        elsif @md.cmd =~/e/: id,file='plaintext Unix (UTF-8) (endnotes)',@md.fn[:plain]
+        elsif @md.cmd =~/A/: id,file='plaintext dos (UTF-8) (footnotes)',@md.fn[:plain]
+        elsif @md.cmd =~/E/: id,file='plaintext dos (UTF-8) (endnotes)',@md.fn[:plain]
         else                id,file='plaintext (UTF-8)',@md.fn[:plain]
         end
           summarize(id,file)
         end
-        if FileTest.file?("#@base_path/#{@md.fn[:wmap]}")==true
-          id,file='Wordmap (rudimentary index in html)',@md.fn[:wmap]
+        if FileTest.file?("#@base_path/#{@md.fn[:concordance]}")==true
+          id,file='Concordance (wordmap)',@md.fn[:concordance]
           summarize(id,file)
         end
-        if FileTest.file?("#@base_path/#@fns.tex")==true
-          id,file='LaTeX (portrait)','#@fns.tex'
+        if FileTest.file?("#@base_path/#{@md.fns}.tex")==true
+          id,file='LaTeX (portrait)',"#{@md.fns}.tex"
           summarize(id,file)
         end
-        if FileTest.file?("#@base_path/#@fns.tex")==true
-          id,file='LaTeX (landscape)','#@fns.landscape.tex'
+        if FileTest.file?("#@base_path/#{@md.fns}.tex")==true
+          id,file='LaTeX (landscape)',"#{@md.fns}.landscape.tex"
           summarize(id,file)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:digest]}")==true
-          id,file='Digest/DCC - Document Content Certificate (md5)',@md.fn[:digest]
+          id,file="Digest/DCC - Document Content Certificate (#@dg)",@md.fn[:digest]
           summarize(id,file)
         end
       end
       def published_versions
         if FileTest.file?("#@base_path/sisu_manifest.html")==true
-          id,file='Markup (SiSU source)',@fns
+          id,file='Markup (SiSU source)',@md.fns
           languages(id,file)
         end
       end
       def language_versions
         if FileTest.file?("#@base_path/sisu_manifest.html")==true
-          id,file='Markup (SiSU source)',@fns
+          id,file='Markup (SiSU source)',@md.fns
           published_languages(id,file)
         end
       end
       def source_tests
-        if @fns =~/\._sst$/                                                  #% decide whether to extract and include requested/required documents
-          req=@fns.gsub(/(.+)?\._sst$/,"\\1.ssm") #watch strange
-          #req=@fns.gsub(/(.+)?\.t([0-3])$/,"\\1.r\\2")
+        if @md.fns =~/\._sst$/                                                  #% decide whether to extract and include requested/required documents
+          req=@md.fns.gsub(/(.+)?\._sst$/,"\\1.composite.sst") #watch strange
           if FileTest.file?("#@base_path/#{req}")==true
             id,file='Markup Composite File (SiSU source)',req
             summarize_source(id,file)
           end
         end
-        #p "#@base_path/#@fns"
-        if FileTest.file?("#@base_path/#@fns")==true
-          id,file='Markup (SiSU source)',@fns
+        if FileTest.file?("#@base_path/#{@md.fns}")==true
+          id,file='Markup (SiSU source)',@md.fns
           summarize_source(id,file)
         end
-        if FileTest.file?("#@base_path/sisudoc.tgz")==true
-          id,file='SiSU doc (tar gzip)','sisudoc.tgz'
+        if FileTest.file?("#@base_path/sisupod.tgz")==true
+          id,file='SiSU doc (tar gzip)','sisupod.tgz'
           summarize_source(id,file)
         end
-        #if FileTest.file?("#@base_path/#@fns.meta")==true
-        #  id,file='Markup (SiSU source)','#@fns.meta'
+        if FileTest.file?("#@base_path/#{@md.fnb}")==true and @md.fnb =~/\.kdi$/
+          id,file='Kdissert (.kdi source)',@md.fnb
+          summarize_source(id,file)
+        end
+        #if FileTest.file?("#@base_path/#{@md.fns}.meta")==true
+        #  id,file='Markup (SiSU source)','#{@md.fns}.meta'
         #  summarize(id,file)
         #end
-        #if FileTest.file?("#@base_path/#@fns.tgz")==true
-        #  id,file='SiSUdoc (tar gzip)','#@fns.tgz'
+        #if FileTest.file?("#@base_path/#{@md.fns}.tgz")==true
+        #  id,file='sisupod (tar gzip)','#{@md.fns}.tgz'
         #  summarize(id,file)
         #end
       end
       def metadata_tests
         if @md.dc_title
-          id,info='DC Title',@md.dc_title
+          id,info=@translate.dc_title,@md.dc_title
           metadata(id,info)
         end
         if @md.title
-          id,info='Title',@md.title
+          id,info=@translate.title,@md.title
           metadata(id,info)
         end
         if @md.subtitle
-          id,info='Subtitle',@md.subtitle
+          id,info=@translate.subtitle,@md.subtitle
           metadata(id,info)
         end
         if @md.dc_creator
-          id,info='DC Creator',@md.dc_creator
+          id,info=@translate.creator,@md.dc_creator
           metadata(id,info)
         end
         if @md.dc_contributor
-          id,info='DC Contributor',@md.dc_contributor
+          id,info=@translate.contributor,@md.dc_contributor
           metadata(id,info)
         end
         if @md.translator
-          id,info='Translator',@md.translator
+          id,info=@translate.translator,@md.translator
           metadata(id,info)
         end
         if @md.illustrator
-          id,info='Illustrator',@md.illustrator
+          id,info=@translate.illustrator,@md.illustrator
           metadata(id,info)
         end
         if @md.dc_publisher
-          id,info='DC Publisher',@md.dc_publisher
+          id,info=@translate.publisher,@md.dc_publisher
           metadata(id,info)
         end
         if @md.prepared_by
-          id,info='Prepared by',@md.prepared_by
+          id,info=@translate.prepared_by,@md.prepared_by
           metadata(id,info)
         end
         if @md.digitized_by
-          id,info='Digitized by',@md.digitized_by
+          id,info=@translate.digitized_by,@md.digitized_by
           metadata(id,info)
         end
         if @md.dc_subject
-          id,info='DC Subject',@md.dc_subject
+          id,info=@translate.subject,@md.dc_subject
           metadata(id,info)
         end
         if @md.dc_description
-          id,info='DC Description',@md.dc_description
+          id,info=@translate.dc_description,@md.dc_description
           metadata(id,info)
         end
         if @md.abstract
-          id,info='Abstract',@md.abstract
+          id,info=@translate.abstract,@md.abstract
           metadata(id,info)
         end
         if @md.dc_type
-          id,info='DC Type',@md.dc_type
+          id,info=@translate.type,@md.dc_type
           metadata(id,info)
         end
         #if @md.owner
@@ -305,95 +316,95 @@ module SiSU_Manifest
         #  metadata(id,info)
         #end
         if @md.dc_rights
-          id,info='DC Rights',@md.dc_rights
+          id,info=@translate.rights,@md.dc_rights
           metadata(id,info)
         end
         if @md.dc_date
-          id,info='DC Date',@md.dc_date
+          id,info=@translate.date,@md.dc_date
           metadata(id,info)
         end
         if @md.dc_date_created
-          id,info='DC Date created',@md.dc_date_created
+          id,info=@translate.date_created,@md.dc_date_created
           metadata(id,info)
         end
         if @md.dc_date_issued
-          id,info='DC Date issued',@md.dc_date_issued
+          id,info=@translate.date_issued,@md.dc_date_issued
           metadata(id,info)
         end
         if @md.dc_date_available
-          id,info='DC Date available',@md.dc_date_available
+          id,info=@translate.date_available,@md.dc_date_available
           metadata(id,info)
         end
         if @md.dc_date_modified
-          id,info='DC Date modified',@md.dc_date_modified
+          id,info=@translate.date_modified,@md.dc_date_modified
           metadata(id,info)
         end
         if @md.dc_date_valid
-          id,info='DC Date valid',@md.dc_date_valid
+          id,info=@translate.date_valid,@md.dc_date_valid
           metadata(id,info)
         end
-        if @md.dc_language[:name]
-          id,info='DC Language',@md.dc_language[:name]
+        if @md.dc_language and @md.dc_language[:name]
+          id,info=@translate.language,@md.dc_language[:name]
           metadata(id,info)
         end
-        if @md.original_language[:name]
-          id,info='Original Language',@md.original_language[:name]
+        if @md.language_original and @md.language_original[:name]
+          id,info=@translate.language_original,@md.language_original[:name]
           metadata(id,info)
         end
         if @md.dc_format
-          id,info='DC Format',@md.dc_format
+          id,info=@transate.format,@md.dc_format
           metadata(id,info)
         end
         if @md.dc_identifier
-          id,info='DC Identifier',@md.dc_identifier
+          id,info=@translate.identifier,@md.dc_identifier
           metadata(id,info)
         end
         if @md.dc_source
-          id,info='DC Source',@md.dc_source
+          id,info=@translate.source,@md.dc_source
           metadata(id,info)
         end
         if @md.dc_relation
-          id,info='DC Relation',@md.dc_relation
+          id,info=@translate.relation,@md.dc_relation
           metadata(id,info)
         end
         if @md.dc_coverage
-          id,info='DC Coverage',@md.dc_coverage
+          id,info=@translate.coverage,@md.dc_coverage
           metadata(id,info)
         end
         if @md.keywords
-          id,info='Keywords',@md.keywords
+          id,info=@translate.keywords,@md.keywords
           metadata(id,info)
         end
         if @md.comments
-          id,info='Comments',@md.comments
+          id,info=@translate.comments,@md.comments
           metadata(id,info)
         end
         if @md.cls_loc
-          id,info='Classify Library Of Congress',@md.cls_loc
+          id,info=@translate.cls_loc,@md.cls_loc
           metadata(id,info)
         end
         if @md.cls_dewey
-          id,info='Classify Dewey',@md.cls_dewey
+          id,info=@translate.cls_dewey,@md.cls_dewey
           metadata(id,info)
         end
         if @md.cls_pg
-          id,info='Classify Project Gutenberg',@md.cls_pg
+          id,info=@translate.cls_gutenberg,@md.cls_pg
           metadata(id,info)
         end
         if @md.cls_isbn
-          id,info='Classify ISBN',@md.cls_isbn
+          id,info=@translate.cls_isbn,@md.cls_isbn
           metadata(id,info)
         end
         if @md.prefix_a
-          id,info='Prefix (a)',@md.prefix_a
+          id,info=@translate.prefix_a,@md.prefix_a
           metadata(id,info)
         end
         if @md.prefix_b
-          id,info='Prefix (b)',@md.prefix_b
+          id,info=@translate.prefix_b,@md.prefix_b
           metadata(id,info)
         end
         if @md.fns
-          id,info='Sourcefile',@md.fns
+          id,info=@translate.sourcefile,@md.fns
           metadata(id,info)
         end
         if @md.en[:mismatch] > 0
@@ -401,32 +412,31 @@ module SiSU_Manifest
           metadata(id,info)
         end
         if @md.wc_words
-          id,info='Word Count approximate',@md.wc_words
+          id,info=@translate.word_count,@md.wc_words
           metadata(id,info)
         end
         if @md.dgst
-          id,info='Sourcefile Digest (md5)',@md.dgst[1]
+          id,info="#{@translate.sourcefile_digest} (#@dg)",@md.dgst[1]
           metadata(id,info)
         end
-        if @md.rc_vnumber
-          id,info='Document (RCS/CVS) number',@md.rc_vnumber
+        if @md.sc_number
+          id,info=@translate.sc_number,@md.sc_number
           metadata(id,info)
         end
-        if @md.rc_date
-          id,info='Document (RCS/CVS) date',"#{@md.rc_date} at #{@md.rc_time}"
+        if @md.sc_date
+          id,info=@translate.sc_date,"#{@md.sc_date} at #{@md.sc_time}"
           metadata(id,info)
         end
         if @md.generated
-          id,info='Document (metaverse) last generated',@md.generated
+          id,info=@translate.last_generated,@md.generated
           metadata(id,info)
         end
-        if @md.sisuversion
-          #p @md.sisuversion
-          id,info='Generated by',"#{@md.sisuversion[:project]} #{@md.sisuversion[:version]} #{@md.sisuversion[:date_stamp]} (#{@md.sisuversion[:date]})"
+        if @md.sisu_version
+          id,info=@translate.sisu_version,"#{@md.sisu_version[:project]} #{@md.sisu_version[:version]} #{@md.sisu_version[:date_stamp]} (#{@md.sisu_version[:date]})"
           metadata(id,info)
         end
-        if @md.rubyversion
-          id,info='Ruby version',@md.rubyversion
+        if @md.ruby_version
+          id,info=@translate.ruby_version,@md.ruby_version
           metadata(id,info)
         end
       end
@@ -456,10 +466,11 @@ module SiSU_Manifest
 <title>
 SiSU manifest: #{@md.title}
 </title>
-<meta name="sourcefile" content="#@fns" />
+<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
+<meta name="sourcefile" content="#{@md.fns}" />
 <link rel="generator" href="http://www.jus.uio.no/sisu" />
 <link rel="shortcut icon" href="../_sisu/image/rb7.ico" />
-<link rel="stylesheet" href="../#{@dir.style}/html.css" type="text/css" />
+<link rel="stylesheet" href="../#{@env.style}/html.css" type="text/css" />
 </head>
 <body bgcolor="#ffffff" text="#000000" link="#003090" lang="en" xml:lang="en">
 <table summary="band" border="0" cellpadding="3" cellspacing="0">
@@ -471,9 +482,9 @@ WOK
           published_versions
           @manifest[:html] << '</table>'
           @manifest[:html] <<<<WOK
-<h2 class="small"><a name="output">SiSU manifest of generated output</a></h2>
+<h2 class="small"><a name="output">#{@translate.manifest_description_output}</a></h2>
 <table summary="normal text css" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">
-<tr> <th class="left"><p class="bold">filename</p></th><th class="left"><p class="bold">description</p></th><th class="right"><p class="right"><b>file size</b></p><p class="tiny_right">(kB)</p></th></tr>
+<tr> <th class="left"><p class="bold">#{@translate.filename}</p></th><th class="left"><p class="bold">#{@translate.description}</p></th><th class="right"><p class="right"><b>#{@translate.file_size}</b></p><p class="tiny_right">(kB)</p></th></tr>
 
 WOK
           output_tests
@@ -484,9 +495,9 @@ WOK
           source_tests
           @manifest[:html] << '</table>'
           @manifest[:html] <<<<WOK
-<h2 class="small"><a name="metadata">SiSU manifest of document metadata</a></h2>
+<h2 class="small"><a name="metadata">#{@translate.manifest_description_metadata}</a></h2>
 <table summary="normal text css" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">
-<tr> <th class="left"><p class="bold">metadata</p></th><th class="left"><p class="bold">description</p></th></tr>
+<tr> <th class="left"><p class="bold">#{@translate.metadata}</p></th><th class="left"><p class="bold">#{@translate.description}</p></th></tr>
 WOK
           metadata_tests
           @manifest[:html] <<<<WOK
@@ -494,16 +505,16 @@ WOK
 WOK
           @manifest[:html] <<<<WOK
 <table summary="normal text css" width="90%" border="0" bgcolor="white" cellpadding="2" align="center">
-<tr><th class="left"><p class="bold"><a name="links">metadata suggested links:</a></p></th></tr>
+<tr><th class="left"><p class="bold"><a name="links">#{@translate.suggested_links}:</a></p></th></tr>
 WOK
           links_tests
           @manifest[:html] <<<<WOK
 </table>
 WOK
           @manifest[:html] <<<<WOK
-<h2 class="small"><a name="languages">Document Language Versions, manifests</a></h2>
+<h2 class="small"><a name="languages">#{@translate.language_version_list}</a></h2>
 <table summary="normal text css" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">
-<tr> <th class="left"><p class="bold">filename</p></th><th class="left"><p class="bold">description</p></th><th class="right"><p class="right">&nbsp;</p></th></tr>
+<tr> <th class="left"><p class="bold">#{@translate.filename}</p></th><th class="left"><p class="bold">#{@translate.description}</p></th><th class="right"><p class="right">&nbsp;</p></th></tr>
 
 WOK
           language_versions
@@ -513,7 +524,7 @@ WOK
 </html>
 WOK
           output
-        rescue: SiSU_Errors::Info_error.new($!,$@,@cf,@fns).error
+        rescue: SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
         ensure
         end
       end
