@@ -5,8 +5,8 @@
    * http://www.jus.uio.no/sisu/SiSU/download
 
  * Description: Syntax for markup, input markup syntaxes, determined here
-   * $Id$
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005 Ralph Amissah
+
+ * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Ralph Amissah
 
  * License: GPL 2 or later
 
@@ -40,7 +40,7 @@
   *  Standard SiSU meta-markup syntax, and the
   *  Standard SiSU object citation numbering and system
   
-  © Ralph Amissah 1997, current 2005.
+  © Ralph Amissah 1997, current 2006.
   All Rights Reserved.
 
  * Ralph Amissah: ralph@amissah.com
@@ -69,7 +69,7 @@ module Syntax
       elsif defined? @mkp.make_italic[:str]
         /#@http_m|#{bold_line}|#@manmkp_ital#{tail_m_ital}|#{@mkp.make_italic[:str]}#{tail_m_ital}|\S+/
       end
-      @manmkp_bold='^!_\s.+?(?:\n|$)|[*!b]\\{.+?\\}[*!b]|[*!b][a-zA-Z0-9\-_]+[*!b]'
+      @manmkp_bold='^!_\s.+?(?:\n|$)|[*!b]\\{.+?\\}[*!b]|[*!][a-zA-Z0-9\-_]+[*!]'
       @line_scan_bold=if (defined? @md.make_bold[:str] and @md.make_bold[:str]) and (defined? @mkp.make_bold[:str] and @mkp.make_bold[:str])
         /#@http_m|#{bold_line}|(?:#@manmkp_bold|#{@md.make_bold[:str]}|#{@mkp.make_bold[:str]})#{tail_m_bold}|\S+/
       elsif (defined? @md.make_bold[:str] and @md.make_bold[:str])
@@ -97,7 +97,7 @@ module Syntax
     def wordlist_italics(line)
       line=line.dup
       if (defined? @md.make_italic[:str] and @md.make_italic[:str]) or (defined? @mkp.make_italic[:str] and @mkp.make_italic[:str])
-        line=if line !~/^(0~|%+\s)/  #!~/^(?:[0-6]~|!_|%+\s)/
+        line= if line !~/^(0~|%+\s)/  #!~/^(?:[0-6]~|!_|%+\s)/
           word=line.scan(@line_scan_ital) 
           word.flatten!
           word.compact!
@@ -229,10 +229,8 @@ module Syntax
         line.gsub!(/\\\\/i,'&#092;')                                                   #escaped special character
         line.gsub!(/\\\*/i,'&#042;')                                                   #escaped special character
         line.gsub!(/\\\!/i,'&#033;')                                                   #escaped special character
-        line.gsub!(/(?:^| )\*~(\S+)/i," <:name#\\1>")                                   #html name marker <a name="\\1"></a>
-        #line.gsub!(/(?:^| )\*~(\S+)/i,"<:name#\\1>")                                   #html name marker <a name="\\1"></a>
-        line.gsub!(/([56]~)(\S+)(.+)/,"\\1\\2 \\3 <:name#\\2>")                        #html name marker <a name="\\1"></a>, however at present takes you to correct position within sub-toc, will nneed to clean from sub-toc leaving in main body only
-        #p line i!f line =~/my_sisu/
+        line.gsub!(/(?:^| )\*~([a-z0-9._-]+)/i,' <:name#\1>')                          #html name marker <a name="\\1"></a>
+        line.gsub!(/^([56]~)(\S+)(.+)/,"\\1\\2 \\3 <:name#\\2>")                        #html name marker <a name="\\1"></a>, however at present takes you to correct position within sub-toc, will nneed to clean from sub-toc leaving in main body only
         line.gsub!(/(^| )\{~\^ (.+?)\s*\}((?:https?|ftp):\S+)\s+~\{(.+?)\}~/,"\\1{ \\2 }\\3 ~{ \\3 \\4 }~") # watch
         #line.gsub!(/(^| )\{~\^ (.+?)\s*\}(http:\S+)\s+~\{(.+?)(<[0-9a-f]{32}>)\}~/,"\\1{ \\2 }\\3 ~{ \\3 \\4 \\5}~") # watch
         line.gsub!(/(^| )\{~\^ (.+?)\s*\}((?:https?|ftp):\S+?)(,?)?(?:\s|$)/,"\\1{ \\2 }\\3\\4 ~{ \\3 }~ ") #text url endnote url shortcut {~^ [text] }http://url is { [text] }http://url ~{ http://url }~ [plus adjustment for commas]
