@@ -5,8 +5,8 @@
    * http://www.jus.uio.no/sisu/SiSU/download
 
  * Description: plaintext text generation, stripped plaintext output (unix, linefeed)
-   * $Id$
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005 Ralph Amissah
+
+ * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Ralph Amissah
 
  * License: GPL 2 or later
 
@@ -40,7 +40,7 @@
   *  Standard SiSU meta-markup syntax, and the
   *  Standard SiSU object citation numbering and system
   
-  © Ralph Amissah 1997, current 2005.
+  © Ralph Amissah 1997, current 2006.
   All Rights Reserved.
 
  * Notes: tidy -ascii index.xml >> index.tidy
@@ -49,25 +49,23 @@
                   ralph.amissah@gmail.com
 =end
 module SiSU_Plaintext
-  require "#{SiSU_lib}/metaverse"
-  require "#{SiSU_lib}/sysenv"
+  require SiSU_lib + '/metaverse'
+  require SiSU_lib + '/sysenv'
   include SiSU_Env
   include SiSU_Param
   include SiSU_Viz
-  require "#{SiSU_lib}/plaintext_format"
+  require SiSU_lib + '/plaintext_format'
   include Format
-  require "#{SiSU_lib}/common_flatfile"
+  require SiSU_lib + '/common_flatfile'
   pwd=Dir.pwd
   @@txt=SiSU_Viz::Txt.new
   @@alt_id_count,@@alt_id_count,@@tablehead,@@number_of_cols=0,0,0,0
   @@tablefoot=''
   class Source
-    def initialize(fns,cf)
-      @fns,@cf=fns,cf
-      @fnb=fns.gsub(/\.[_-]?sst$/,'')
-      @@endnotes_para=Array.new
-      if @fns =~/(.+?)\.[_-]?sst$/
-        case cf
+    def initialize(opt)
+      @opt=opt
+      if @opt.fns =~/(.+?)\.[_-]?sst$/
+        case @opt.cmd
         when /[af]/: @@dostype='unix footnotes'
         when /e/:    @@dostype='unix endnotes'
         when /[AF]/: @@dostype='msdos footnotes'
@@ -78,82 +76,89 @@ module SiSU_Plaintext
     end
     def read
       begin
-        @md=SiSU_Param::Parameters.new(@fns,@cf).get
-        @dir=SiSU_Env::Info_dir.new(@fns)
-        path=SiSU_Env::Info_dir.new(@fns).tell_output_path
-        tool=if @cf =~/[MVv]/: "#{@dir.text_editor} #{path}/#{@md.fnb}/#{@md.fn[:plain]}"
+        @md=SiSU_Param::Parameters.new(@opt).get
+        @env=SiSU_Env::Info_dir.new(@opt.fns)
+        path=SiSU_Env::Info_dir.new(@opt.fns).tell_output_path
+        tool=if @opt.cmd =~/[MVv]/: "#{@env.text_editor} #{path}/#{@md.fnb}/#{@md.fn[:plain]}"
         else ''
         end
-        tell=SiSU_Screen::Ansi.new(@cf,'Plaintext',tool)
-        tell.greenHiBlue unless @cf =~/q/
-        tell=SiSU_Screen::Ansi.new(@cf,@fns,"#{@dir.tell_output_path}/#{@md.fnb}/#{@md.fn[:plain]}")
-        tell.flow if @cf =~/[MV]/
-        my_make=SiSU_Env::Create_file.new(@cf,@fns)
-        @metaverse_array=SiSU_Metaverse::Source.new(@fns,@cf).get # metaverse file drawn here
+        tell=SiSU_Screen::Ansi.new(@opt.cmd,'Plaintext',tool)
+        tell.green_hi_blue unless @opt.cmd =~/q/
+        tell=SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.tell_output_path}/#{@md.fnb}/#{@md.fn[:plain]}")
+        tell.flow if @opt.cmd =~/[MV]/
+        my_make=SiSU_Env::Create_file.new(@opt.cmd,@opt.fns)
+        @metaverse_array=SiSU_Metaverse::Source.new(@opt).get # metaverse file drawn here
         SiSU_Plaintext::Source::Scroll.new(@metaverse_array,@md).songsheet
         SiSU_Env::Info_skin.new(@md).select
-      rescue: SiSU_Errors::Info_error.new($!,$@,@cf,@fns).error
+      rescue: SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
       end
     end
     private
     class Split_text_object <Source
-      require "#{SiSU_lib}/plaintext_format"
+      require SiSU_lib + '/plaintext_format'
       include SiSU_Viz
       include Format
       @@alt_id_count=0
+      @@dp=nil
       attr_reader :format,:lev,:text,:ocn,:lev_para_ocn
       def initialize(para)
         @para=para
         @format,@ocn='null','null'
+        #@format,@ocn=nil,nil
+        @@dp ||=SiSU_Env::Info_dir.new.digest_pattern
       end
       def lev_segname_para_ocn 
-        if @para =~/^(\d~|<:.+?>).+?<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>.*/
-          if /(([1-6])~(\S+))\s+(\S.+?)<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/im.match(@para)
+        if @para =~/^(\d~|<:.+?>).+?<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>.*/
+          if /(([1-6])~(\S+))\s+(\S.+?)<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/im.match(@para)
             @format,@lev,segname,@text,@ocn=$1,$2,$3,$4,$5
-          elsif  /(([1-6])~)\s+(\S.+?)<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/im.match(@para)
+          elsif  /(([1-6])~)\s+(\S.+?)<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/im.match(@para)
             @format,@lev,@text,@ocn=$1,$2,$3,$4
-          elsif /<:(.+?)>\s*(\S.+?)<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/im.match(@para)
+          elsif /<:(.+?)>\s*(\S.+?)<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/im.match(@para)
             @format,@text,@ocn=$1,$2,$3,$4
-          elsif /(([1-6])~(\S+))\s+(\S.+?)<~(\d+);(?:\w|[0-6]:)\d+;[um]\d+><[0-9a-f]{32}:[0-9a-f]{32}>/im.match(@para)
+          elsif /(([1-6])~(\S+))\s+(\S.+?)<~(\d+);(?:\w|[0-6]:)\d+;[um]\d+><#{@@dp}:#{@@dp}>/im.match(@para)
             @@alt_id_count+=1
             @format,@lev,segname,@text,@ocn=$1,$2,$3,$4,"x#{@@alt_id_count}"
             #@format="#@format~#{segname}" # 
-          elsif  /(([1-6])~)\s+(\S.+?)<~(\d+);[um]\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/im.match(@para)
+          elsif  /(([1-6])~)\s+(\S.+?)<~(\d+);[um]\d+;\w\d+><#{@@dp}:#{@@dp}>/im.match(@para)
             @@alt_id_count+=1
             @format,@lev,@text,@ocn=$1,$2,$3,"x#{@@alt_id_count}"
           end
         else
-          if /(.+?)<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/im.match(@para)
+          if /(.+?)<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/im.match(@para)
             @text,@ocn=$1,$2
           end
-          if @para !~/<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>|^$/ #added 2002w06
+          if @para !~/<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>|^$/ #added 2002w06
             @text=/(.+?)/im.match(@para)[1]
           end
           if /^((\d)~(?:~\S+)?)\s+(.+)/im.match(@para)
             @format,@lev,@text=$1,$2,$3
           end
         end
-        @lev_para_ocn=if @para =~/.+<~\d+;(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/
-          Format::Format_text_object.new(@format.dup,@text,@ocn)
+        format=@format.dup
+        @lev_para_ocn=if @para =~/.+<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/
+          Format::Format_text_object.new(format,@text,@ocn)
         else
-          Format::Format_text_object.new(@format.dup,@text,'<~(\d+);[um]\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>')
+          Format::Format_text_object.new(format,@text,"<~(\d+);[um]\d+;\w\d+><#{@@dp}:#{@@dp}>")
         end
         self
       end
     end
     class Scroll <Source
-      require "#{SiSU_lib}/common_text"
+      require SiSU_lib + '/common_text'
       include SiSU_text_utils
+      @@endnotes_para=Array.new
       @@plaintext=Hash.new
       @@plaintext[:body],@@plaintext[:open],@@plaintext[:close],@@plaintext[:head],@@plaintext[:metadata],@@plaintext[:tail],@@plaintext[:endnotes]=Array.new,Array.new,Array.new,Array.new,Array.new,Array.new,Array.new
-      @@url=SiSU_Viz::Url.new
-      def initialize(data='',md='')
+      @@dp=nil
+      def initialize(data,md)
         @data,@md=data,md
         @margin=SiSU_Viz::Margin.new
-        @regx=/^(?:(?:<:p[bn]>\s*)?\d~(?:(\S+))?\s+)?(.+?)\s*<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>$/ #m # 2004w18 pb pn removal added
+        @@dp ||=SiSU_Env::Info_dir.new.digest_pattern
+        @regx=/^(?:(?:<:p[bn]>\s*)?\d~(?:(\S+))?\s+)?(.+?)\s*<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>$/ #m # 2004w18 pb pn removal added
+        @url=SiSU_Viz::Url.new
         @tab="\t"
-        @br=case md.cf
+        @br=case md.cmd
         when /[af]/
           @@dostype='unix footnotes'
           "\n"
@@ -178,7 +183,7 @@ module SiSU_Plaintext
       end
       # Used for extraction of endnotes from paragraphs
       def extract_endnotes(para='')
-        notes=para.scan(/~\{(\d+\s+.+?)\s*<[0-9a-f]{32}>\}~/)
+        notes=para.scan(/~\{([\d*+]+\s+.+?)\s*<#{@@dp}>\}~/)
         @n=Array.new
         notes.each do |n| #high cost to deal with <br> appropriately within plaintext, consider
           n=n.dup.to_s
@@ -193,12 +198,12 @@ module SiSU_Plaintext
         end
         notes=@n.flatten
         notes.each do |e| 
-          util=if e.to_s =~/^\[\d+\]:/: SiSU_text_utils::Paragraph.new(e.to_s,70,4,1)
-          else                          SiSU_text_utils::Paragraph.new(e.to_s,70,1,1)
+          util=if e.to_s =~/^\[[\d*+]+\]:/: SiSU_text_utils::Paragraph.new(e.to_s,70,4,1)
+          else                             SiSU_text_utils::Paragraph.new(e.to_s,70,1,1)
           end
           wrap=util.line_wrap
-          if wrap =~ /^\s*\d+\s+.+?\s*\Z/m
-            wrap.gsub!(/^(\s*)(\d+)\s+(.+?)\s*\Z/m, <<GSUB
+          if wrap =~ /^\s*[\d*+]+\s+.+?\s*\Z/m
+            wrap.gsub!(/^(\s*)([\d*+]+)\s+(.+?)\s*\Z/m, <<GSUB
 
 \\1[\\2]: \\3
 GSUB
@@ -222,33 +227,33 @@ GSUB
 WOK
       end
       def plaintext_tail
-        generator="Generated by: #{@md.sisuversion[:project]} #{@md.sisuversion[:version]} of #{@md.sisuversion[:date_stamp]} (#{@md.sisuversion[:date]})"  if @md.sisuversion[:version]
+        generator="Generated by: #{@md.sisu_version[:project]} #{@md.sisu_version[:version]} of #{@md.sisu_version[:date_stamp]} (#{@md.sisu_version[:date]})"  if @md.sisu_version[:version]
         lastdone="Last Generated on: #{Time.now}"
-        rubyv="Ruby version: #{@md.rubyversion}"
-        vc=if @md.rc_info
-          "Source file:    #{@md.rc_filename}#{@br}Version number: #{@md.rc_vnumber}#{@br}Version date:   #{@md.rc_date}#{@br}"
+        rubyv="Ruby version: #{@md.ruby_version}"
+        sc=if @md.sc_info
+          "Source file:    #{@md.sc_filename}#{@br}Version number: #{@md.sc_number}#{@br}Version date:   #{@md.sc_date}#{@br}"
         else ''
         end
         @@plaintext[:tail] <<<<WOK
 #@br
 Other versions of this document: #@br
 manifest:
-   #{@@url.root_http}/#{@md.fnb}/#{@md.fn[:manifest]}#@br
+   #{@url.root_http}/#{@md.fnb}/#{@md.fn[:manifest]}#@br
 html:
-   #{@@url.root_http}/#{@md.fnb}/#{@md.fn[:toc]}#@br
+   #{@url.root_http}/#{@md.fnb}/#{@md.fn[:toc]}#@br
 pdf:
-   #{@@url.root_http}/#{@md.fnb}/#{@md.fn[:pdf_p]}
-   #{@@url.root_http}/#{@md.fnb}/#{@md.fn[:pdf_l]}#@br
+   #{@url.root_http}/#{@md.fnb}/#{@md.fn[:pdf_p]}
+   #{@url.root_http}/#{@md.fnb}/#{@md.fn[:pdf_l]}#@br
 plaintext (plain text):
-   #{@@url.root_http}/#{@md.fnb}/#{@md.fn[:plain]}#@br
+   #{@url.root_http}/#{@md.fnb}/#{@md.fn[:plain]}#@br
 at:
-   #{@@url.site}#@br
+   #{@url.site}#@br
 
-#{vc}
+#{sc}
 * #{generator}
 * #{rubyv}
 * #{lastdone}
-* SiSU #{@@url.sisu}
+* SiSU #{@url.sisu}
 WOK
       end
       def plaintext_structure(para='',lv='',ocn='',hname='') #% Used to extract the structure of a document
@@ -257,10 +262,9 @@ WOK
         n3=lv + 2
         lv=nil if lv == 0
         extract_endnotes(para)
-        para.gsub!(/\{(\d+)\s+(?:.+?)\}~/, "[\\1]") # endnote marker marked up
-        #para.strip!
+        para.gsub!(/~\{([\d*+]+)\s+(?:.+?)\}~/,'[^\1]') # endnote marker marked up
         wrapped=if para[@regx]
-          paragraph="#{para[@regx, 2]}"
+          paragraph="#{para[@regx,2]}"
           if paragraph.include? '<:i1>'
             paragraph.gsub!(/<:i1>/,'')
             util=SiSU_text_utils::Paragraph.new(paragraph,70,2)
@@ -272,36 +276,36 @@ WOK
           times=wrapped.length
           times=70 if times > 70
           @@plaintext[:body] << case lv
-          when 1:      wrapped.upcase << @br << '*'*times << @br*2
-          when 2..3:   wrapped.upcase << @br << '='*times << @br*2
-          when 4:      wrapped.upcase << @br << '-'*times << @br*2
-          when 5..6:   wrapped.upcase << @br << '.'*times << @br*2
+          when 1:      wrapped.upcase << @br << '*'*times << @br
+          when 2..3:   wrapped.upcase << @br << '='*times << @br
+          when 4:      wrapped.upcase << @br << '-'*times << @br
+          when 5..6:   wrapped.upcase << @br << '.'*times << @br
           end
         else
-          @@plaintext[:body] << wrapped # main text, contents, body KEEP
-          if @@endnotes_para and @@dostype =~/footnote/ #edit out to switch off endnotes following paragraph to which they belong
-            @@plaintext[:body] << @br*2 # << @br
-            @@endnotes_para.each {|e| @@plaintext[:body] << e << @br} 
-          elsif @@endnotes_para and @@dostype =~/endnote/
-            @@plaintext[:body] << @br*2 # << @br
-          end
+          @@plaintext[:body] << wrapped << @br # main text, contents, body KEEP
+        end
+        if @@endnotes_para and @@dostype =~/footnote/ #edit out to switch off endnotes following paragraph to which they belong
+          @@plaintext[:body] << @br
+          @@endnotes_para.each {|e| @@plaintext[:body] << e << @br} 
+        elsif @@endnotes_para and @@dostype =~/endnote/
+          @@plaintext[:body] << @br*2
         end
         @@endnotes_para=Array.new
       end
       # Used to clean words
       def tidywords(wordlist)
         wordlist.each do |x|
-          #x.gsub!(/&/, '&amp;') unless x =~/&\S+;/
+          #x.gsub!(/&/,'&amp;') unless x =~/&\S+;/
         end
       end
       def markup                                                               # Used for major markup instructions
         data=@data
-        dir=SiSU_Env::Info_dir.new(@fns)
+        dir=SiSU_Env::Info_dir.new(@md.fns)
         @data_mod,@endnotes,@level,@cont,@copen,@plaintext_contents_close=Array.new,Array.new,Array.new,Array.new,Array.new,Array.new
         @rcdc=false
         (0..6).each { |x| @cont[x]=@level[x]=false } 
         (4..6).each { |x| @plaintext_contents_close[x]='' } 
-        plaintext_tail #($1, $2)
+        plaintext_tail #($1,$2)
         fix=Array.new
         #data.each do |para| #high cost to deal with <br> appropriately within plaintext, consider
         #  para=para.dup
@@ -317,64 +321,43 @@ WOK
         #end
         #data=@data_mod.flatten
         data.each do |para|
-          para.gsub!(/.+?<-#>/i, '')                                           # remove dummy headings (used by html) #check
-          para.gsub!(/_\*\s+/, '* ')                                           # bullet markup, marked down
-          para.gsub!(/&#169;/, '©')                                           # bullet markup, marked down
-          para.gsub!(/&amp;/, '&')                                           # bullet markup, marked down
-          para.gsub!(/<sup>(.+?)<\/sup>/, "^\\1^")
-          para.gsub!(/<sub>(.+?)<\/sub>/, "[\\1]")
-          para.gsub!(/<i>(.+?)<\/i>/, "/\\1/")
-          para.gsub!(/<b>(.+?)<\/b>/, "*\\1*")
-          para.gsub!(/<u>(.+?)<\/u>/, "_\\1_")
-          para.gsub!(/<:(?:group|poem|alt|code)(?:-end)?>(?:\s+<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>)?/, '')
-          para.gsub!(/<:p[bn]>/mi, '')                                         # remove page breaks
-          para.gsub!(/^\s*<~\d+;(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/i, '') # remove empty lines
-          para.gsub!(/<a href=".+?">(.+?)<\/a>/im, "\\1")
-          para.gsub!(/<:name#\S+?>/, '')                                       # remove name links
-          para.gsub!(/&nbsp;/, ' ')                                            # decide on
-          para.gsub!(/\{(\S+?\.(?:png|jpg)) .+?\}(?:(?:https?|ftp):\/\/\S+|image)/, "    [ \\1 ]") #"[ #{dir.url_images_local}\/\\1 ]")
-          para.gsub!(/^\{\S+?\.(?:png|jpg)\s+.+?"(.*?)"\s*\}\S+/, "[image: \"\\1\"]")
-          para.gsub!(/<!TZ.+/i, '')
-          para.gsub!(/^<!T.+/, "#@br[table: ] <~#>"); 
+          para.gsub!(/.+?<-#>/i,'')                                           # remove dummy headings (used by html) #check
+          para.gsub!(/_\*\s+/,'* ')                                           # bullet markup, marked down
+          para.gsub!(/&#169;/,'©')                                           # bullet markup, marked down
+          para.gsub!(/&amp;/,'&')                                           # bullet markup, marked down
+          para.gsub!(/<sup>(.+?)<\/sup>/,"^\\1^")
+          para.gsub!(/<sub>(.+?)<\/sub>/,"[\\1]")
+          para.gsub!(/<i>(.+?)<\/i>/,"/\\1/")
+          para.gsub!(/<b>(.+?)<\/b>/,"*\\1*")
+          para.gsub!(/<u>(.+?)<\/u>/,"_\\1_")
+          para.gsub!(/<:(?:group|poem|alt|code)(?:-end)?>(?:\s+<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>)?/,'')
+          para.gsub!(/<:p[bn]>/mi,'')                                         # remove page breaks
+          para.gsub!(/^\s*<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/i,'') # remove empty lines
+          para.gsub!(/<a href=".+?">(.+?)<\/a>/im,'\1')
+          para.gsub!(/<:name#\S+?>/,'')                                       # remove name links
+          para.gsub!(/&nbsp;/,' ')                                            # decide on
+          para.gsub!(/\{(\S+?\.(?:png|jpg)) .+?\}(?:(?:https?|ftp):\/\/\S+|image)/,"    [ \\1 ]") #"[ #{dir.url_images_local}\/\\1 ]")
+          para.gsub!(/^\{\S+?\.(?:png|jpg)\s+.+?"(.*?)"\s*\}\S+/,"[image: \"\\1\"]")
+          para.gsub!(/<!TZ.+/i,'')
+          para.gsub!(/^<!T.+/,"#@br[table: ] <~#>"); 
           wordlist=para.scan(/\S+/)
           para=tidywords(wordlist).join(' ').strip
-          if para =~/^0~(\S+)\s+(.+?)$/                                        # for headers
-            case para
-            when /^0~(creator|author)\s+(.+?)$/:  plaintext_metadata('creator', $2)
-            when /^0~(subject)\s+(.+?)$/:         plaintext_metadata($1,$2)
-            when /^0~(description)\s+(.+?)$/:     plaintext_metadata($1,$2)
-            when /^0~(publisher)\s+(.+?)$/:       plaintext_metadata($1,$2)
-            when /^0~(contributor)\s+(.+?)$/:     plaintext_metadata($1,$2)
-            when /^0~(date)\s+(.+?)$/:            plaintext_metadata($1,$2)
-            when /^0~(date\.created)\s+(.+?)$/:   plaintext_metadata($1,$2)
-            when /^0~(date\.issued)\s+(.+?)$/:    plaintext_metadata($1,$2)
-            when /^0~(date\.available)\s+(.+?)$/: plaintext_metadata($1,$2)
-            when /^0~(date\.valid)\s+(.+?)$/:     plaintext_metadata($1,$2)
-            when /^0~(date\.modified)\s+(.+?)$/:  plaintext_metadata($1,$2)
-            when /^0~(type)\s+(.+?)$/:            plaintext_metadata($1,$2)
-            when /^0~(format)\s+(.+?)$/:          plaintext_metadata($1,$2)
-            when /^0~(identifier)\s+(.+?)$/:      plaintext_metadata($1,$2)
-            when /^0~(source)\s+(.+?)$/:          plaintext_metadata($1,$2)
-            when /^0~(language)\s+(.+?)$/:        plaintext_metadata($1,$2)
-            when /^0~(relation)\s+(.+?)$/:        plaintext_metadata($1,$2)
-            when /^0~(coverage)\s+(.+?)$/:        plaintext_metadata($1,$2)
-            when /^0~(rights)\s+(.+?)$/:          plaintext_metadata($1,$2)
-            when /^0~(keywords)\s+(.+?)$/:        plaintext_metadata($1,$2)
-            when /^0~(copyright)\s+(.+?)$/:       plaintext_metadata($1,$2)
-            end
-          end
+          if para =~/^0~(\S+)\s+(.+?)$/ # for headers
+            dc=SiSU_scan::Header_scan.new(@md,para).dublin
+            if dc: plaintext_metadata(dc[0],dc[1])
+	    end
+	  end
           @rcdc=true if @rcdc==false and (para =~/~metadata/ or para =~/1~\s+Document Information/)
           if para !~/(^0~|<ENDNOTES>|<EOF>)/ 
             if para =~@regx #/.+?<~\d+;\w\d+;\w\d+>.*/ #watch change
-              paranum=para[@regx, 3]
+              paranum=para[@regx,3]
               @p_num=Format::Paragraph_number.new(paranum)
             end
             @sto=Split_text_object.new(para).lev_segname_para_ocn
             ### problem in scroll, it appears tables are getting paragraph numbers
             unless @rcdc
-              m=/<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/
+              m=/<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/
               if para =~m and para=~/\S+/
-                #formatMono=Format::MonoSiSU.new(@sto.text) if @sto.format =~/i[12]|null/
                 para=case @sto.format
                 when /^(1)~(?:(\S+))?/
                   plaintext_structure(para,$1,@sto.ocn,$2)
@@ -417,44 +400,44 @@ WOK
                   plaintext_structure(para,nil,nil,nil) #watch may be problematic
                   para
                 end
-              elsif para =~/(Note|Endnotes?)/ and para !~/<~\d+;(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/
-              elsif para =~/(MetaData)/ and para =~/<~(\d+);[um]\d+;\w\d+;[0-9a-f]{32};[0-9a-f]{32}>/ #debug 2003w46 add rc info
+              elsif para =~/(Note|Endnotes?)/ and para !~/<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/
+              elsif para =~/(MetaData)/ and para =~/<~(\d+);[um]\d+;\w\d+><#{@@dp}:#{@@dp}>/ #debug 2003w46 add rc info ####suspect visit
                 #formatMono=MonoSiSU.new('<br /><a name="metadata">MetaData</a>')
                 #para=formatMono.bold_para
-              elsif para.include? 'Owner Details' and para !~/<~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/
+              elsif para.include? 'Owner Details' and para !~/<~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/
                 #formatMono=MonoSiSU.new('<br /><a name="owner.details">Owner Details</a>')
                 #@@plaintext[:owner_details]=formatMono.bold_para
                 #para=''
               elsif para =~/(¡|<!Th?)/i #tables !
               elsif para =~/(.*)<!#!>(.*)/i
-                one, two=$1,$2
+                one,two=$1,$2
                 format_text=Format_text_object.new(one,two)
-                para=format_text.segNoParanum
+                para=format_text.seg_no_paranum
               end
               para='' if (para =~/<a name="n\d+">/ and para =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/) # -endnote
               case para
               when /<:i1>/
                 if (para =~/.*<:#>.*$/)
                   format_text=Format_text_object.new(para,'')
-                  para=format_text.scrIndentOneNoParanum
+                  para=format_text.scr_indent_one_no_paranum
                 end
               when /<:i2>/
                 if (para =~/.*<:#>.*$/)
                   format_text=Format_text_object.new(para,'')
-                  para=format_text.scrIndentOneNoParanum
+                  para=format_text.scr_indent_one_no_paranum
                 end
               end
               if (para !~/#{@margin.txt_0}|#{@margin.txt_1}|#{@margin.txt_2}/)
                 # i don't get the condition for no paranum
               end
               if para =~/<:center>/i
-                one, two=/(.*)<:center>(.*)/i.match(para)[1,2]
-                format_text=Format_text_object.new(one, two)
+                one,two=/(.*)<:center>(.*)/i.match(para)[1,2]
+                format_text=Format_text_object.new(one,two)
                 para=format_text.center
               end
             end
-            para.gsub!(/<!.+!>/i, ' ') if para ## Clean Prepared Text
-            para.gsub!(/<:\S+>/i, ' ') if para ## Clean Prepared Text
+            para.gsub!(/<!.+!>/i,' ') if para ## Clean Prepared Text
+            para.gsub!(/<:\S+>/i,' ') if para ## Clean Prepared Text
           end
         end
       end
