@@ -5,10 +5,8 @@
    * http://www.jus.uio.no/sisu/SiSU/download
 
  * Description: LaTeX generation
-   * arch-tag: latex for pdf (processing, logic) 
-   * $Date$
-   * $Id$
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005 Ralph Amissah
+
+ * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Ralph Amissah
 
  * License: GPL 2 or later
 
@@ -42,21 +40,20 @@
   *  Standard SiSU meta-markup syntax, and the
   *  Standard SiSU object citation numbering and system
   
-  © Ralph Amissah 1997, current 2005.
+  © Ralph Amissah 1997, current 2006.
   All Rights Reserved.
 
  * Ralph Amissah: ralph@amissah.com
                   ralph.amissah@gmail.com
 =end
-module SiSU_Tex
+module SiSU_TeX
   require 'pstore'
-  $program||='tbl'
-  require "#{SiSU_lib}/defaults"
-  require "#{SiSU_lib}/param"
+  require SiSU_lib + '/defaults'
+  require SiSU_lib + '/param'
   include SiSU_Param
   include SiSU_Viz
-  require "#{SiSU_lib}/texpdf_format"
-  include SiSU_Tex_Pdf
+  require SiSU_lib + '/texpdf_format'
+  include SiSU_TeX_Pdf
   @tex_file=@@tex_footnote_array=@@tex_col_w=Array.new
   @@tex_backslash="\\\\"
   @@tex_3='\\\\\\{\\\\\\{' #?? debug crazy
@@ -70,30 +67,28 @@ module SiSU_Tex
   @@n=@@tableheader=@@rights=nil
   @@date=SiSU_Env::Info_date.new
   class Source #Songsheet #<SiSU_Param::MyFiles
-    $program='tbl'
     require 'pstore'
-    require "#{SiSU_lib}/sysenv"
-    require "#{SiSU_lib}/param"
+    require SiSU_lib + '/sysenv'
+    require SiSU_lib + '/param'
     include SiSU_Env
     include SiSU_Param
     include SiSU_Viz
-    require "#{SiSU_lib}/metaverse"
+    require SiSU_lib + '/metaverse'
     include SiSU_Metaverse
-    include SiSU_Tex
-    def initialize(sf,cf)
-      @fns,@cf=sf,cf
-      @fnb=sf[/(.+?)\.[_-]?sst$/,1]
-      @dir=SiSU_Env::Info_dir.new(@fns)
+    include SiSU_TeX
+    def initialize(opt)
+      @opt=opt
+      @env=SiSU_Env::Info_dir.new(@opt.fns)
     end
     def directories
       begin
-        @dir_out_root=@dir.data_o
-        case @fns
+        @dir_out_root=@env.data_o
+        case @opt.fns
         when /\.[_-]?sst$/
-          Dir.mkdir(@dir.data_o) unless FileTest.directory?(@dir.data_o)
-          Dir.mkdir(@dir.tex) unless FileTest.directory?(@dir.tex)
+          Dir.mkdir(@env.data_o) unless FileTest.directory?(@env.data_o)
+          Dir.mkdir(@env.tex) unless FileTest.directory?(@env.tex)
         end
-      rescue: SiSU_Errors::Info_error.new($!,$@,@cf,@fns).error
+      rescue: SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
       end
     end
@@ -102,43 +97,43 @@ module SiSU_Tex
     end
     def songsheet
       begin
-        @md=SiSU_Param::Parameters.new(@fns,@cf).get
-        tell=SiSU_Screen::Ansi.new(@cf,'LaTeX/PDF')
-        tell.greenTitleHi unless @cf =~/q/
-        path=SiSU_Env::Info_dir.new(@fns).tell_output_location
-        tell=SiSU_Screen::Ansi.new(@cf,@fns,"#{@dir.pdf_viewer} #{path}/#{@md.fnb}/#{@md.fn[:pdf_l]}")
-        tell.flow if @cf =~/[MVv]/
-        tell=SiSU_Screen::Ansi.new(@cf,@fns,"#{@dir.pdf_viewer} #{path}/#{@md.fnb}/#{@md.fn[:pdf_p]}")
-        tell.flow if @cf =~/[MVv]/
-        data=IO.readlines(@fns,'')                                             #wasteful, revisit
-        @md=SiSU_Param::Parameters.new(@fns,@cf).get
-        my_make=SiSU_Env::Create_file.new(@cf,@fns)
+        @md=SiSU_Param::Parameters.new(@opt).get
+        tell=SiSU_Screen::Ansi.new(@opt.cmd,'LaTeX/PDF')
+        tell.green_title_hi unless @opt.cmd =~/q/
+        path=SiSU_Env::Info_dir.new(@opt.fns).tell_output_location
+        tell=SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.pdf_viewer} #{path}/#{@md.fnb}/#{@md.fn[:pdf_l]}")
+        tell.flow if @opt.cmd =~/[MVv]/
+        tell=SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.pdf_viewer} #{path}/#{@md.fnb}/#{@md.fn[:pdf_p]}")
+        tell.flow if @opt.cmd =~/[MVv]/
+        data=IO.readlines(@opt.fns,'')                                             #wasteful, revisit
+        @md=SiSU_Param::Parameters.new(@opt).get
+        my_make=SiSU_Env::Create_file.new(@opt.cmd,@opt.fns)
         if @md.flag_pdf
-          $flag=@md.cf                                                         #introduced to pass 0 for no object citation numbers... to texpdf_format
-          @dir_o="#{@dir.data_o}/#@fnb"
+          $flag=@md.cmd                                                         #introduced to pass 0 for no object citation numbers... to texpdf_format
+          @dir_o="#{@env.data_o}/#{@opt.fnb}"
           directories
-          @md.txt_path="#@dir_o/#@fnb"
+          @md.txt_path="#@dir_o/#{@opt.fnb}"
           Dir.mkdir(@dir_o) unless FileTest.directory?(@dir_o)
           filename_index="#{@md.txt_path}/pdf"
           newfilename=filename_index
                                                                                #% needed needs to be reprogrammed !!!
           SiSU_Env::Info_skin.new(@md).select
           SiSU_Viz::Url.new
-          metaverse_array=SiSU_Metaverse::Source.new(@fns,@cf).get             # metaverse file drawn here
-          SiSU_Tex::Source::Tex_create.new(metaverse_array,@md,'landscape').songsheet
-          SiSU_Tex::Source::Tex_create.new(metaverse_array,@md,'portrait').songsheet
+          metaverse_array=SiSU_Metaverse::Source.new(@opt).get             # metaverse file drawn here
+          SiSU_TeX::Source::Tex_create.new(metaverse_array,@md,'landscape').songsheet
+          SiSU_TeX::Source::Tex_create.new(metaverse_array,@md,'portrait').songsheet
           metaverse_array=''
           pwd=Dir.pwd
-          SiSU_Tex::Source::LaTeX_to_pdf.new(@fns,@md).latexrun_selective
+          SiSU_TeX::Source::LaTeX_to_pdf.new(@md).latexrun_selective
           Dir.chdir(pwd)
         else
-          tell=SiSU_Screen::Ansi.new(@cf,'instructed NOT to produce LaTeX/PDF')
-          tell.warn unless @cf =~/q/
+          tell=SiSU_Screen::Ansi.new(@opt.cmd,'instructed NOT to produce LaTeX/PDF')
+          tell.warn unless @opt.cmd =~/q/
         end
-      rescue: SiSU_Errors::Info_error.new($!,$@,@cf,@fns).error
+      rescue: SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
-        unless @cf =~/[MV]/ #check maintenance flag
-          texfiles = Dir["#{@dir.tex}/#{@fns}*"]
+        unless @opt.cmd =~/[MV]/ #check maintenance flag
+          texfiles = Dir["#{@env.tex}/#{@opt.fns}*"]
           texfiles.each do |f| 
             if FileTest.file?(f)
               #puts "removing #{f}"
@@ -155,7 +150,7 @@ module SiSU_Tex
         @@date=SiSU_Env::Info_date.new
         @@flag=Hash.new
         $flag=1 #remove at some stage
-        SiSU_Env::Create_file.new(@cf,@fns).param_instantiate
+        SiSU_Env::Create_file.new(@opt.cmd,@opt.fns).param_instantiate
       end
     end
     private
@@ -163,42 +158,41 @@ module SiSU_Tex
       require 'fileutils'
       include FileUtils #::Verbose
       @@n_lpdf||=0 #change
-      def initialize(fns,md)
-        @fns,@md=fns,md
-        @dir=SiSU_Env::Info_dir.new(@fns)
+      def initialize(md)
+        @md=md
+        @env=SiSU_Env::Info_dir.new(@md.fns)
       end
       def latex_do(texfilename)
         @texfilename=texfilename
-        @fnb=@md.fnb
         @@n_lpdf=@@n_lpdf+1
-        tell=SiSU_Screen::Ansi.new(@md.cf,'portrait ->')
-        tell.darkgreyTitleHi if @md.cf =~/[MVv]/
+        tell=SiSU_Screen::Ansi.new(@md.cmd,'portrait ->')
+        tell.dark_grey_title_hi if @md.cmd =~/[MVv]/
         tex_fn_base=@texfilename.gsub(/\.tex$/,'')
-        cmd=SiSU_Env::System_call.new("#{tex_fn_base}.tex",'',@md.cf)
-        tell=SiSU_Screen::Ansi.new(@md.cf)
-        tell.greyOpen unless @md.cf =~/q/
+        cmd=SiSU_Env::System_call.new("#{tex_fn_base}.tex",'',@md.cmd)
+        tell=SiSU_Screen::Ansi.new(@md.cmd)
+        tell.grey_open unless @md.cmd =~/q/
         2.times { |i| cmd.latex2pdf unless ("#{tex_fn_base}.tex" !~/\w+/) }
-        tell.p_off unless @md.cf =~/q/
-        tell=SiSU_Screen::Ansi.new(@md.cf,'landscape ->')
-        tell.darkgreyTitleHi if @md.cf =~/[MVv]/
-        cmd=SiSU_Env::System_call.new("#{tex_fn_base}.landscape.tex",'',@md.cf)
-        tell.greyOpen
+        tell.p_off unless @md.cmd =~/q/
+        tell=SiSU_Screen::Ansi.new(@md.cmd,'landscape ->')
+        tell.dark_grey_title_hi if @md.cmd =~/[MVv]/
+        cmd=SiSU_Env::System_call.new("#{tex_fn_base}.landscape.tex",'',@md.cmd)
+        tell.grey_open
         2.times { |i| cmd.latex2pdf unless ("#{tex_fn_base}.landscape.tex" !~/\w+/) }
-        tell.p_off unless @md.cf =~/q/
+        tell.p_off unless @md.cmd =~/q/
         pwd=Dir.pwd
-        #fns_l=@fns.gsub(/~/,'-') #this is a sorry fix, but necessary as it appears latex programs like not ~
+        #fns_l=@md.fns.gsub(/~/,'-') #this is a sorry fix, but necessary as it appears latex programs like not ~
         portrait_pdf="#{pwd}/#{tex_fn_base}.pdf"
         landscape_pdf="#{pwd}/#{tex_fn_base}.landscape.pdf"
         if FileTest.file?(portrait_pdf)
-          File.install(portrait_pdf,"#@dir_sisu/#{@fnb}/#{@md.fn[:pdf_p]}")
+          File.install(portrait_pdf,"#@dir_sisu/#{@md.fnb}/#{@md.fn[:pdf_p]}")
           File.unlink(portrait_pdf)
         end
         if FileTest.file?(landscape_pdf)
-          File.install(landscape_pdf,"#@dir_sisu/#{@fnb}/#{@md.fn[:pdf_l]}")
+          File.install(landscape_pdf,"#@dir_sisu/#{@md.fnb}/#{@md.fn[:pdf_l]}")
           File.unlink(landscape_pdf)
         end
-        tell=SiSU_Screen::Ansi.new(@md.cf,@@n_lpdf,'processed (SiSU LaTeX to pdf - using pdfetex aka. pdftex or pdflatex)')
-        tell.genericNumber unless @md.cf =~/q/
+        tell=SiSU_Screen::Ansi.new(@md.cmd,@@n_lpdf,'processed (SiSU LaTeX to pdf - using pdfetex aka. pdftex or pdflatex)')
+        tell.generic_number unless @md.cmd =~/q/
       end
       def latexrun_selective
         begin
@@ -206,34 +200,32 @@ module SiSU_Tex
           Dir.chdir(ep_dir)
           @tex_f_no=0
           info=Hash.new
-          @fns.each do |file|
-            if FileTest.file?("#{ep_dir}/#{file}")
-              if file =~/\.[_-]?sst$/
-                @dirout=SiSU_Env::Info_dir.new(@fns)
-                case file
-                when /\.[_-]?sst$/
-                  if FileTest.directory?(@dir.tex)==true
-                    Dir.chdir(@dir.tex)
-                    @dir_sisu=@dirout.data_o
-                    texfile=file.gsub(/$/,'.tex')
-                    texfile=texfile.gsub(/~/,'-')
-                    if File.exists?(texfile) and File.size(texfile) > 0
-                      @tex_f_no+=1
-                      latex_do(texfile)
-                    else
-                      puts "\tzero file size #{@dir.tex}/#{file}"
-                    end
+          if FileTest.file?("#{ep_dir}/#{@md.fns}")
+            if @md.fns =~/\.[_-]?sst$/
+              @dirout=SiSU_Env::Info_dir.new(@md.fns)
+              case @md.fns
+              when /\.[_-]?sst$/
+                if FileTest.directory?(@env.tex)==true
+                  Dir.chdir(@env.tex)
+                  @dir_sisu=@dirout.data_o
+                  texfile=@md.fns.gsub(/$/,'.tex')
+                  texfile=texfile.gsub(/~/,'-')
+                  if File.exists?(texfile) and File.size(texfile) > 0
+                    @tex_f_no+=1
+                    latex_do(texfile)
+                  else
+                    puts "\tzero file size #{@env.tex}/#{@md.fns}"
                   end
                 end
               end
-            else
-              puts "\n#{@cX.fuschia}FILE NOT FOUND:#{@cX.off} << #{file} >> - requested latex system processing skipped\n"
             end
+          else
+            puts "\n#{@cX.fuschia}FILE NOT FOUND:#{@cX.off} << #{file} >> - requested latex system processing skipped\n"
           end
           lst=Dir["*.{aux,log,out}"]
           lst.each {|file| File.unlink(file)} if lst
           #touch("#{@dir_pdf}index.html") #correct @dir_pdf appears to contain slash / and should not
-        rescue: SiSU_Errors::Info_error.new($!,$@,@fns,@md.cf).error
+        rescue: SiSU_Errors::Info_error.new($!,$@,@md.fns,@md.cmd).error
         end
       end
     end
@@ -246,17 +238,16 @@ module SiSU_Tex
       @@tex_head_portrait=Array.new
       @@tex_head_landscape=Array.new
       @@flag_group,@@flag_code=false,false
-      @@prefix_b=nil
+      @@dp,@@prefix_b=nil,nil
       def initialize(data,md,orientation)
         @data,@md,@orientation=data,md,orientation
-        @fns=@md.fns
-        @fnb=@fns[/(.+?)\.[_-]?sst$/,1]
-        @dir=SiSU_Env::Info_dir.new(@fns)
+        @env=SiSU_Env::Info_dir.new(@md.fns)
         @vz=Hash.new
         @vz[:tex]=Hash.new
-        @tex=SiSU_Tex_Pdf::SoloTex.new(@orientation,@md)
+        @tex=SiSU_TeX_Pdf::Use_TeX.new(@md,@orientation)
         @url=SiSU_Viz::Url.new
         @txt=SiSU_Viz::Txt.new
+        @@dp ||=SiSU_Env::Info_dir.new.digest_pattern
       end
       def songsheet
         begin
@@ -264,33 +255,33 @@ module SiSU_Tex
           SiSU_Viz::Url.new
           data=@data
           @@rights=nil
-          tell=SiSU_Screen::Ansi.new(@md.cf,"pdfTex #@orientation")
-          tell.txt_grey unless @md.cf =~/q/
+          tell=SiSU_Screen::Ansi.new(@md.cmd,"pdfTex #@orientation")
+          tell.txt_grey unless @md.cmd =~/q/
           if @md.dc_rights
             use=@md.dc_rights.dup #dup is necessary, else contents of :rights changed
-            doMono=SiSU_Tex_Pdf::MonoTex.new(use,@md)
+            do_mono=SiSU_TeX_Pdf::Format_text_object.new(@md,use)
             copymark=if @md.creator_copymark: '{\\begin{small}\\raisebox{1ex}{\\copyright}\\end{small}} '
             else ''
             end
-            copyright=doMono.special_characters_safe.gsub(/^\s*Copyright/, copymark)
+            copyright=do_mono.special_characters_safe.gsub(/^\s*Copyright/, copymark)
             @@rights||="\n #{@@tex_backslash*2}[3]\\ \\linebreak #{copyright}"
           end
           if @md.prefix_b
-            doMono=SiSU_Tex_Pdf::MonoTex.new(@md.prefix_b,@md)
-            prefix_b=doMono.special_characters_safe
+            do_mono=SiSU_TeX_Pdf::Format_text_object.new(@md,@md.prefix_b)
+            prefix_b=do_mono.special_characters_safe
             @@prefix_b="\n #{@@tex_backslash*2}[3]\\ \\linebreak \\ #{prefix_b}\n" unless @@prefix_b
           end
           if @md.markup.to_s !~/url_png/
             munge=Tex_create.new(@data,@md,@orientation).pre
-            munge=Tex_create.new(munge.collect,@md,@orientation).footnote
+            munge=Tex_create.new(munge,@md,@orientation).footnote
             if @md.flag_tables
-              munge=Tex_create.new(munge.collect,@md,@orientation).tables
+              munge=Tex_create.new(munge,@md,@orientation).tables
             end
-            munge=Tex_create.new(munge.collect,@md,@orientation).numbering
-            munge=Tex_create.new(munge.collect,@md,@orientation).markup
-            Tex_create.new(munge.collect,@md,@orientation).output
+            munge=Tex_create.new(munge,@md,@orientation).numbering
+            munge=Tex_create.new(munge,@md,@orientation).markup
+            Tex_create.new(munge,@md,@orientation).output
           end
-        rescue: SiSU_Errors::Info_error.new($!,$@,@fns,@md.cf).error
+        rescue: SiSU_Errors::Info_error.new($!,$@,@md.fns,@md.cmd).error
         ensure
         end
       end
@@ -308,8 +299,8 @@ module SiSU_Tex
           pg.each do |pg|
           if pg =~/<!Th?¡\s+c/i: @md.flag_tables=true # KLUDGE get from param
           end
-          doMono=SiSU_Tex_Pdf::MonoTex.new(pg,@md)
-          @tex_file << doMono.special_characters
+          do_mono=SiSU_TeX_Pdf::Format_text_object.new(@md,pg)
+          @tex_file << do_mono.special_characters
           end
         end
         data=@tex_file.delete_if {|x| x =~/^\s*0#{@@tex_1}/}
@@ -326,14 +317,10 @@ module SiSU_Tex
             @@tex_footnote_array << para2
           end
           # EMBEDDED FOOTNOTES / ENDNOTES should be straightforward but not quite a synch.
-          # BUG bug -> have problems with endnotes in headers
           footnote=Array.new
-          #if para =~/~\\\{\d+\s+/ # note escape not necessary in front of ~ has implications for many other matches #debug note
-          #  para.gsub!(/\\\~\\\{(\d+)\s+(.+?)\\\}\\\~/m, "\\footnote[\\1]{%\n\\smallskip{} \\noindent \\2} ") #removed space before \\footnote 2004w21, watch
-          #end
-          #p para if para =~/~\\\{\d+\s+/
-          if para =~/~\\\{\d+\s+/                                                # note escape not necessary in front of ~ has implications for many other matches #debug note
-            para.gsub!(/\\\~\\\{(\d+)\s+(.+?)<[0-9a-f]{32}>\\\}\\\~/m, "\\footnote[\\1]{%\n \\2} ") #removed space before \\footnote 2004w21, watch
+          if para =~/~\\\{[\d*+]+\s+/                                                # note escape not necessary in front of ~ has implications for many other matches #debug note
+            para.gsub!(/\\\~\\\{(\d+)\s+(.+?)<#{@@dp}>\\\}\\\~/m,"\\footnote[\\1]{%\n \\2} ") #removed space before \\footnote 2004w21, watch
+            para.gsub!(/\\~\\\{([*+]+)\s+(.+?)<#{@@dp}>\\\}\\~/m,"\\FootnoteA{\\1}{%\n \\2} ") #work on asterisk footnotes
           end
           @tex_file << para
         end
@@ -345,7 +332,7 @@ module SiSU_Tex
         @@tableheader=0
         data.each do |para|
           if para =~/¡|<!T/i
-            do_mono=SiSU_Tex_Pdf::MonoTex.new(para,@md)
+            do_mono=SiSU_TeX_Pdf::Format_text_object.new(@md,para)
             para=do_mono.longtable_landscape if @orientation =~/landscape/ # using longtable latex package
             para=do_mono.longtable_portrait if @orientation =~/portrait/ # using longtable latex package
           end
@@ -358,7 +345,7 @@ module SiSU_Tex
         @@tableheader=0
         data.each do |para|
           if para =~/¡|<!T/i
-            doMono=SiSU_Tex_Pdf::MonoTex.new(para,@md)
+            do_mono=SiSU_TeX_Pdf::Format_text_object.new(@md,para)
           end
           @tex_file << para 
         end
@@ -368,7 +355,7 @@ module SiSU_Tex
         if type =~/code/: para
           #para = '\begin{footnotesize} \begin{ttfamily} ' + para + ' \end{ttfamily} \end{footnotesize}'
         elsif para !~/(\\begin\{tabular\}.*|\\end\{tabular\}|&|#{@@tex_backslash*2})\s*$/ #check
-          para.gsub!(/(.+)/mi, "\n#{@tex.skip_small} \\1 #{@tex.skip_small}\n")
+          para.gsub!(/(.+)/m,"\n#{@tex.skip_small} \\1 #{@tex.skip_small}\n")
         else para
         end
       end
@@ -377,14 +364,14 @@ module SiSU_Tex
         @tex_file=Array.new
         md=Hash.new
                                                                                  #% document headers watch special characters in title & subtitle: glark "\{\{~(sub)?title.+?[$&%#_\{\}]" *.(lm|er)??  
-        home=@txt.home.gsub(/<(br|p)>|<\/\s*(br|p)>|<(br|p)\s*\/>|\\\\/i, " - ") #no line splitting in heading neither html nor latex
-        title=@md.title.gsub(/<(br|p)>|<\/\s*(br|p)>|<(br|p)\s*\/>|\\\\/i, " - ") #no line splitting in heading neither html nor latex 
-        subtitle=@md.subtitle.gsub(/<(br|p)>|<\/\s*(br|p)>|<(br|p)\s*\/>|\\\\/i, " - ") if @md.subtitle #no line splitting in heading neither html nor latex
-        @duotex=SiSU_Tex_Pdf::Format_text_object.new(@orientation,"#{home}: - #{title} #{subtitle}", @md) #.new
+        home=@txt.home.gsub(/<(br|p)>|<\/\s*(br|p)>|<(br|p)\s*\/>|\\\\/i,' - ') #no line splitting in heading neither html nor latex
+        title=@md.title.gsub(/<(br|p)>|<\/\s*(br|p)>|<(br|p)\s*\/>|\\\\/i,' - ') #no line splitting in heading neither html nor latex 
+        subtitle=@md.subtitle.gsub(/<(br|p)>|<\/\s*(br|p)>|<(br|p)\s*\/>|\\\\/i,' - ') if @md.subtitle #no line splitting in heading neither html nor latex
+        orient=SiSU_TeX_Pdf::Format_text_object.new(@md,@orientation,"#{home}: - #{title} #{subtitle}") #.new
         if @orientation =~/portrait/
-          @@tex_head_portrait << @duotex.a4_orientation 
+          @@tex_head_portrait << orient.a4_orientation 
         elsif @orientation =~/landscape/
-          @@tex_head_landscape << @duotex.a4_orientation
+          @@tex_head_landscape << orient.a4_orientation
         end
         @tex_file <<<<WOK
 #{@tex.header}#{@tex.footer}
@@ -392,18 +379,18 @@ module SiSU_Tex
 \\makeatother
 \\begin{document}
 WOK
-        sisu_rc_footnote=if @md.rc_info: @tex.doc_rc_info_footnote_full
-        else                             @tex.doc_rc_info_footnote_brief
+        sisu_rc_footnote=if @md.sc_info: @tex.doc_sc_info_footnote_full
+        else                             @tex.doc_sc_info_footnote_brief
         end
         #@copymark='{\\begin{small}\\raisebox{1ex}{\\copyright}\\end{small}}'
         @copymark=if @md.creator_copymark: '^\copyright'
         else                               ''
         end
         if @orientation =~/landscape/ # using longtable latex package
-          @tex_file << SiSU_Tex_Pdf::Format_text_object.new(@md.title,@md.subtitle,@md).title_landscape
+          @tex_file << SiSU_TeX_Pdf::Format_text_object.new(@md,@md.title,@md.subtitle).title_landscape
           if @md.dc_creator
-            doMono=SiSU_Tex_Pdf::MonoTex.new(@md.dc_creator,@md)
-            creator=doMono.special_characters
+            do_mono=SiSU_TeX_Pdf::Format_text_object.new(@md,@md.dc_creator)
+            creator=do_mono.special_characters
             @tex_file << if @md.creator_home
               <<WOK
 
@@ -417,7 +404,7 @@ WOK
           else "\\date"
           end
         else #portrait
-          @tex_file << SiSU_Tex_Pdf::Format_text_object.new(@md.title,@md.subtitle,@md).title_portrait
+          @tex_file << SiSU_TeX_Pdf::Format_text_object.new(@md,@md.title,@md.subtitle).title_portrait
           if @md.dc_creator
             creator=@md.dc_creator
             @tex_file << if @md.creator_home
@@ -436,12 +423,13 @@ WOK
 \\pagenumbering{roman}\\maketitle
 \\pagestyle{fancy}
 WOK
+        #@tex_file << @tex.newpage #newpage clearpage depending on portrait or landscape
         @tex_file << "\\newpage\n"
         @tex_file << @@rights if @md.dc_rights #if @orientation =~/landscape/
         @tex_file << @@prefix_b if @md.prefix_b
         @tex_file << @tex.sisu_rights
-        @tex_file << if @md.rc_info: @tex.doc_rc_info
-        else                         @tex.doc_no_rc_info
+        @tex_file << if @md.sc_info: @tex.doc_sc_info
+        else                         @tex.doc_no_sc_info
         end
         @tex_file << @tex.newpage 
         @tex_file <<<<WOK
@@ -454,7 +442,7 @@ WOK
         @tex_file << @tex.newpage 
         @group_collect=Array.new
         data.each do |para|                                                      #% case follows with levels 1-6 indents & graphics
-          mono=SiSU_Tex_Pdf::MonoTex.new(para,@md)
+          mono=SiSU_TeX_Pdf::Format_text_object.new(@md,para)
           if para =~/<:(code|alt|poem|group)>/ or @@flag_group==true
             if para =~/<:(code|alt|poem|group)>/
               @lineone=case para 
@@ -474,7 +462,8 @@ WOK
             end
             if x =~/(?:code|alt|poem|group)-end/
               regx=/(\\+marginpar\{\\+begin\{tiny\}\d+\\+end\{tiny\}\})/ 
-              y=if para =~regx: regx.match(para)[1] 
+              y=if para =~regx
+                regx.match(para)[1] 
               else ''
               end
               para.gsub!(regx,'')
@@ -504,7 +493,7 @@ WOK
             when /^\s*<:image\s+/:     mono.image
             when /\}image/:            mono.png
             when /\}(?:https?|ftp)/
-              para=mono.http
+              para=mono.http(@orientation)
               para=enclose(para)
             else
               para.strip!
@@ -583,7 +572,8 @@ WOK
       def number_titles
         data=@data
         @tex_file=Array.new
-        input=%{#{@md.markup}}[/(num_top\s*=\s*(\d?))?/m, 2] # else default usually 4  # this was a bit of a trick required to pass nil to input if nothing matched... #puts input
+        input=@md.num_top
+        #input=%{#{@md.markup}}[/(num_top\s*=\s*(\d?))?/m,2] # else default usually 4  # this was a bit of a trick required to pass nil to input if nothing matched... #puts input
         num_top=input.to_i
         t_no1=t_no2=t_no3=t_no4=0
         no1,no2,no3,no4=num_top,(num_top + 1),(num_top + 2),(num_top + 3);
@@ -606,16 +596,16 @@ WOK
         @tex_file=Array.new
         paranumber=0
         data.each do |para|
-          if para =~/<\\~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/ and para !~/\\end\{longtable\}|<EOF>/ #catch <!TZ!>
-            m=/(.+?)<\\~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/im
-            parablock=para[m, 1]
-            paranum=para[m, 2]
-            do_duo=SiSU_Tex_Pdf::Format_text_object.new(parablock,paranum,@md)
-            para=do_duo.paraNum if parablock
-          elsif para =~/^<~\d+;(?:[oh]|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/ #2005 this is added for tables, rationalise
-            m=/<~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/im
+          if para =~/<\\~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/ and para !~/\\end\{longtable\}|<EOF>/ #catch <!TZ!>
+            m=/(.+?)<\\~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/im
+            parablock=para[m,1]
+            paranum=para[m,2]
+            do_duo=SiSU_TeX_Pdf::Format_text_object.new(@md,parablock,paranum)
+            para=do_duo.para_num if parablock
+          elsif para =~/^<~\d+;(?:[oh]|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/ #2005 this is added for tables, rationalise
+            m=/<~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/im
             paranum=para[m,1]
-            para.gsub!(/<~\d+;(?:[oh]|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/,'')
+            para.gsub!(/<~\d+;(?:[oh]|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/,'')
             para="\\marginpar{\\begin{tiny}#{paranum}\\end{tiny}}" + para
           #elsif para =~/<!T.+?!~\d+?>/
           elsif para =~/^<~\d+;(?:[oh]|[0-6]:)\d+;\w\d+>/ #extra 2005 this is added for tables, rationalise
@@ -624,7 +614,7 @@ WOK
             para.gsub!(/<~\d+;(?:[oh]|[0-6]:)\d+;\w\d+>/,'')
             para="\\marginpar{\\begin{tiny}#{paranum}\\end{tiny}}" + para
           elsif para =~/\\end\{longtable\}/ #catch <!TZ!>
-            para.gsub!(/<\\~\d+>|<\\~(\d+);(?:[ohm]|[0-6]:)\d+;\w\d+><[0-9a-f]{32}:[0-9a-f]{32}>/,'')
+            para.gsub!(/<\\~\d+>|<\\~(\d+);(?:[ohm]|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>/,'')
             para.gsub!(/<\\~\d+>|<\\~(\d+);(?:[ohm]|[0-6]:)\d+;\w\d+>/,'') #extra
           end
           @tex_file << para
@@ -640,15 +630,15 @@ WOK
           para.gsub!(/^\s+/, '')
           @tex_file << para
         end
-        fns_l=@fns.gsub(/~/,'-') #this is a sorry fix, but necessary as it appears latex programs like not ~
+        fns_l=@md.fns.gsub(/~/,'-') #this is a sorry fix, but necessary as it appears latex programs like not ~
         if @orientation =~/landscape/    #@tex_file << "\n<!EOF!>"
-          filename_tex_landscape=File.new("#{@dir.tex}/#{fns_l}.landscape.tex",'w+')
+          filename_tex_landscape=File.new("#{@env.tex}/#{fns_l}.landscape.tex",'w+')
           filename_tex_landscape << @@tex_head_landscape 
           @tex_file.each {|para| filename_tex_landscape.puts para, "\n" unless para.empty?}
           filename_tex_landscape.close
           @@tex_head_landscape=Array.new
         elsif @orientation =~/portrait/
-          filename_tex_portrait=File.new("#{@dir.tex}/#{fns_l}.tex",'w+')
+          filename_tex_portrait=File.new("#{@env.tex}/#{fns_l}.tex",'w+')
           filename_tex_portrait << @@tex_head_portrait
           @tex_file.each {|para| filename_tex_portrait.puts para, "\n" unless para.empty?} 
           filename_tex_portrait.close
